@@ -99,9 +99,9 @@ void CAttachedFileView::OnInitialUpdate()
 	COLORREF m_colorEdit;
 	// backgroud color.
 	m_colorEdit = RGB(
-		app->GetProfileInt("EditViewColor", "BkColorR", 0),
-		app->GetProfileInt("EditViewColor", "BkColorG", 0),
-		app->GetProfileInt("EditViewColor", "BkColorB", 0));
+		app->GetProfileInt("EditViewColor", "BkColorR", DEF_BKG_COLOR_R),
+		app->GetProfileInt("EditViewColor", "BkColorG", DEF_BKG_COLOR_G),
+		app->GetProfileInt("EditViewColor", "BkColorB", DEF_BKG_COLOR_B));
 	lc.SetBkColor(m_colorEdit);
 	// backgroud color of text.
 	m_colorEdit = RGB(
@@ -123,28 +123,28 @@ void CAttachedFileView::OnInitialUpdate()
 	// if mail is resurected from draft and file is attached, need to set attached file
 	if(df->m_me.GetMode() != ME_MODE_PGP){
 		CString path;
-		for(int i=1; i<df->m_me.HowManyPart(); i++){ // i=0 is mail body, so start from i=1.
+		int max = df->m_me.HowManyPart();
+		for(int i=1; i<max; i++){ // i=0 is mail body, so start from i=1.
 			if(df->m_me.GetMultipartType(i) == "application/pgp-keys"){
 				this->AddPgpKey();
 			}else{
 				// in order to get icon of file, save file into attached directory at first
-				if(!g_is_there(app->m_app_path+"\\temp")) // if no folder for attached, create.
+				if(!g_is_there(app->m_app_path+"\\temp")) // if no tmp folder, create.
 					_mkdir(app->m_app_path+"\\temp");
 				path = app->m_app_path+"\\temp\\"+df->m_me.GetMultipartFileName(i);
 				FILE* file = fopen(path, "wb");
 				CString body = df->m_me.GetMultipartBody(i);
 				body.Remove('\r');
 				body.Remove('\n');
-				char* in = body.GetBuffer(0);
 				char* out = new char[body.GetLength()];
-				int len = from64tobits(out, in, strlen(in));
+				int len = from64tobits(out, body, body.GetLength());
 				fwrite(out, sizeof(char), len, file);
 				fclose(file);
-				delete[] out;
+				delete [] out;
 				body.ReleaseBuffer();
 
 				// add item
-				this->AddFile(path.GetBuffer(0));
+				this->AddFile(path);
 				path.ReleaseBuffer();
 			}
 		}
@@ -156,7 +156,7 @@ void CAttachedFileView::OnInitialUpdate()
 	}else{
 		strBackgroundFilePath = app->m_skin.getSkinIniPath() + "\\" + app->m_skin.getAttachedFileViewBackBmp();
 	}
-	SetBkImage(strBackgroundFilePath);
+//	SetBkImage(strBackgroundFilePath);
 }
 
 void CAttachedFileView::OnRclick(NMHDR* pNMHDR, LRESULT* pResult)
@@ -172,6 +172,11 @@ void CAttachedFileView::OnRclick(NMHDR* pNMHDR, LRESULT* pResult)
 		CMenu menu;
 
 		menu.LoadMenu(IDR_MULTIPART_DRAFT_POPUP);
+		CPochyApp* pPochyApp = (CPochyApp*)::AfxGetApp();
+		if (pPochyApp != NULL)
+		{
+			pPochyApp->m_pluginManager.OnInitMenu(menu.GetSubMenu(0)->GetSafeHmenu(), POCHY_MENU_DRAFT_ATTACHED_FILE_VIEW);
+		}
 		CMenu *pPopup = menu.GetSubMenu(0);
 		pPopup->TrackPopupMenu(TPM_LEFTALIGN | TPM_RIGHTBUTTON, (int)pt.x, (int)pt.y, this);
 	}	
@@ -188,7 +193,8 @@ void CAttachedFileView::ReArrange()
 	p.y = 0;
 	GetClientRect(rect);
 	width = rect.right;
-	for(i=0;i<lc.GetItemCount();i++){
+	int max = lc.GetItemCount();
+	for(i=0; i<max; i++){
 		lc.SetItemPosition(i,p);
 		lc.GetItemRect(i,rect,LVIR_BOUNDS);
 		if(width <= rect.right && i){
@@ -205,7 +211,6 @@ void CAttachedFileView::ExecuteFile()
 {
 	CPochyApp *app = (CPochyApp *)AfxGetApp();
 
-//	CListCtrl& listCtrl = GetListCtrl();
 	CString file_name;
 	CString body;
 	CStringArray buf;
@@ -220,16 +225,13 @@ void CAttachedFileView::ExecuteFile()
 		body = df->m_me.GetMultipartBody(m_index+1);
 		body.Remove('\r');
 		body.Remove('\n');
-		char* in = body.GetBuffer(0);
 		char* out = new char[body.GetLength()];
-		int len = from64tobits(out, in, strlen(in));
+		int len = from64tobits(out, body, body.GetLength());
 		fwrite(out, sizeof(char), len, file);
 		fclose(file);
-		delete[] out;
-		body.ReleaseBuffer();
+		delete [] out;
 	}
 	ShellExecute(NULL, "open", app->m_app_path+"\\temp\\"+df->m_me.GetMultipartFileName(m_index+1), NULL, NULL, SW_SHOW);
-	return;
 }
 
 void CAttachedFileView::OnDblclk(NMHDR* pNMHDR, LRESULT* pResult) 
@@ -289,7 +291,7 @@ void CAttachedFileView::OnKeyDown(UINT nChar, UINT nRepCnt, UINT nFlags)
 	CListView::OnKeyDown(nChar, nRepCnt, nFlags);
 }
 
-void CAttachedFileView::AddFile(LPSTR file_path)
+void CAttachedFileView::AddFile(LPCTSTR file_path)
 {
 	CString path = file_path;
 
@@ -317,3 +319,18 @@ void CAttachedFileView::AddPgpKey()
 	CListCtrl &lc = this->GetListCtrl();
 	lc.InsertItem(lc.GetItemCount(), "application/pgp-keys", this->m_image.GetImageCount()-1);
 }
+
+BOOL CAttachedFileView::OnCommand(WPARAM wParam, LPARAM lParam) 
+{
+	CPochyApp *pPochyApp = (CPochyApp *)AfxGetApp();
+	if (pPochyApp != NULL)
+	{
+		CMainFrame *pMainFrame = (CMainFrame*)pPochyApp->m_pMainWnd;
+		if (pMainFrame != NULL)
+		{
+			pMainFrame->CallPluginCallback(this->GetSafeHwnd(), LOWORD(wParam));
+		}
+	}
+	
+	return CListView::OnCommand(wParam, lParam);
+}
