@@ -25,6 +25,7 @@
 #include "ExEditor.h"
 #include "DraftAddressBookDlg.h"
 #include "DraftSendDlg.h"
+#include "TimeEx.h"
 
 #ifdef _DEBUG
 #define new DEBUG_NEW
@@ -44,8 +45,6 @@ CDraftFrame::CDraftFrame()
 {
 	CGpg gpg;
 	CPochyApp *app = (CPochyApp*)AfxGetApp();
-//	CMainFrame *mf = (CMainFrame *)app->m_pMainWnd;
-	this->m_hide = FALSE;
 	this->m_flag = FALSE;
 	this->m_hide_attach = FALSE;
 	this->m_button_gpg = app->m_gpg_enable;
@@ -96,6 +95,7 @@ BEGIN_MESSAGE_MAP(CDraftFrame, CFrameWnd)
 	ON_UPDATE_COMMAND_UI(ID_DRAFT_GPG, OnUpdateGpg)
 	ON_WM_KEYDOWN()
 	ON_COMMAND(ID_SWITCH_VIEW, OnSwitchView)
+	ON_WM_SYSCOMMAND()
 	//}}AFX_MSG_MAP
 	ON_COMMAND(WM_END, OnEnd)
 	ON_COMMAND(WM_PROGCREATE, OnProgCreate)
@@ -166,22 +166,72 @@ int CDraftFrame::OnCreate(LPCREATESTRUCT lpCreateStruct)
 
 	m_pAddrsV->SetFocus();
 
+	if (app != NULL)
+	{
+		HMENU hMenu = ::GetMenu(GetSafeHwnd());
+		if (hMenu != NULL)
+		{
+			// GPG Ƃ̓j[\ɂ
+			// j[폜Əς邽ߐԍZbg
+			int nGPGMenuPos = 2;
+			int nHelpMenuPos = 3;
+			CGpg gpg;
+			if (!gpg.Check())
+			{
+				::DeleteMenu(hMenu, nGPGMenuPos, MF_BYPOSITION);
+				nGPGMenuPos = -1; // 폜ꂽ邵Ƃ -1
+				nHelpMenuPos--;
+			}
+			if (nGPGMenuPos == -1)
+			{
+				::DrawMenuBar(GetSafeHwnd());
+			}
+
+			for (int i = 0; i < ::GetMenuItemCount(hMenu); i++)
+			{
+				HMENU hSubMenu = ::GetSubMenu(hMenu, i);
+				if (hSubMenu != NULL)
+				{
+					POCHY_MENU_TYPE nMenuType = POCHY_MENU_DRAFT_MAIL;
+					switch (i)
+					{
+					case 0: nMenuType = POCHY_MENU_DRAFT_MAIL; break;
+					case 1: nMenuType = POCHY_MENU_DRAFT_VIEW; break;
+					default:
+						{
+							if (i == nGPGMenuPos)
+							{
+								nMenuType = POCHY_MENU_DRAFT_GPG;
+							}
+							else if (i == nHelpMenuPos)
+							{
+								nMenuType = POCHY_MENU_DRAFT_HELP;
+							}
+						}
+						break;
+					}
+					app->m_pluginManager.OnInitMenu(hSubMenu, nMenuType);
+				}
+			}
+		}
+		HMENU hSystemMenu = ::GetSystemMenu(GetSafeHwnd(), FALSE);
+		if (hSystemMenu != NULL)
+		{
+			app->m_pluginManager.OnInitMenu(hSystemMenu, POCHY_MENU_DRAFT_SYSTEM);
+//			::GetSystemMenu(GetSafeHwnd(), TRUE);
+		}
+	}
+
 	return 0;
 }
 
 void CDraftFrame::OnSend()
 {
 	CPochyApp* app=(CPochyApp*)AfxGetApp();
-	this->EnableWindow(FALSE);
 
 	CString body;
 	this->m_pEditV->GetText(body);
 
-	this->m_send_dlg = new CDraftSendDlg();
-	this->m_send_dlg->Create(IDD_DRAFT_SEND_STATUS, this);
-	this->m_send_dlg->ShowWindow(SW_SHOW);
-	this->m_send_dlg->CenterWindow();
-
 	this->m_me.SetTo(m_pAddrsV->GetTo());
 	this->m_me.SetCc(m_pAddrsV->GetCc());
 	this->m_me.SetBcc(m_pAddrsV->GetBcc());
@@ -189,14 +239,32 @@ void CDraftFrame::OnSend()
 	this->m_me.SetSubject(m_pAddrsV->GetSubject());
 	this->m_me.SetReplyTo(m_pAddrsV->GetReplyTo());
 	this->m_me.SetXMailer(app->GetProfileString("Customize", "XMailer", X_MAILER));
-	// 12 Apr 2003 15:40:48 +0900
-	CTime time = CTime::GetCurrentTime();
-	this->m_me.SetDate(time.Format("%d %b %Y %H:%M:%S ")+DEF_TIME_ZONE);
+	// get date
+	// below is mosyly by hiro-san
+	tzset();
+	CString offset;
+	// get current system time zone offset
+	offset.Format("%+03d%02d",(-_timezone)/60/60,(-_timezone)/60%60);
+	CTimeEx time(CTime::GetCurrentTime().GetTime(), offset);
+	// change to default time zone offset
+	time.SetNewOffset(app->m_time_zone_offset);
+	this->m_me.SetDate(time.GetMailFormatDate());
+
 	// setting mail body.
 	if(this->m_me.GetMode() == ME_MODE_NONE)
 		this->m_me.SetMultipartBody(0, body);
 
-	AfxBeginThread(SendMail, this);
+	if (app->m_pluginManager.OnSendMail(m_me.GetMail(ME_GET_SEND)) == PR_SEND_OK)
+	{
+		this->EnableWindow(FALSE);
+
+		this->m_send_dlg = new CDraftSendDlg();
+		this->m_send_dlg->Create(IDD_DRAFT_SEND_STATUS, this);
+		this->m_send_dlg->ShowWindow(SW_SHOW);
+		this->m_send_dlg->CenterWindow();
+
+		AfxBeginThread(SendMail, this);
+	}
 }
 
 void CDraftFrame::OnSaveToDraft()
@@ -229,26 +297,23 @@ void CDraftFrame::OnProgDestroy()
 
 BOOL CDraftFrame::OnCreateClient(LPCREATESTRUCT lpcs, CCreateContext* pContext) 
 {
-//	CPochyApp* app=(CPochyApp*)AfxGetApp();
-//	CMainFrame *mf = (CMainFrame *)app->m_pMainWnd;
+	this->m_split_attachedfile_others.CreateStatic(this, 2, 1);
+	this->m_split_attachedfile_others.SetStaticBorder(TRUE);
+	this->m_split_address_mailedit.CreateStatic(&m_split_attachedfile_others, 2, 1, WS_CHILD|WS_VISIBLE|WS_BORDER, m_split_attachedfile_others.IdFromRowCol(0,0));
 
-	this->m_wndSplit.CreateStatic(this, 2, 1);
-	this->m_wndSplit.SetStaticBorder(TRUE);
-	this->m_wndSplit1.CreateStatic(&m_wndSplit, 2, 1, WS_CHILD|WS_VISIBLE|WS_BORDER, m_wndSplit.IdFromRowCol(0,0));
+	this->m_split_address_mailedit.CreateView(0, 0, RUNTIME_CLASS(CAddressView), CSize(0,DEF_ADDRESS_HEIGHT), pContext);
+	this->m_split_address_mailedit.CreateView(1, 0, RUNTIME_CLASS(CMailEditView), CSize(0, 0), pContext);
+	this->m_split_address_mailedit.NoBorder();
+	this->m_split_address_mailedit.SetStaticBorder(TRUE);
+	this->m_split_attachedfile_others.CreateView(1, 0, RUNTIME_CLASS(CAttachedFileView), CSize(0, 0), pContext);
 
-	this->m_wndSplit1.CreateView(0, 0, RUNTIME_CLASS(CAddressView), CSize(0,DEF_ADDRESS_HEIGHT), pContext);
-	this->m_wndSplit1.CreateView(1, 0, RUNTIME_CLASS(CMailEditView), CSize(0, 0), pContext);
-	this->m_wndSplit1.NoBorder();
-	this->m_wndSplit1.SetStaticBorder(TRUE);
-	this->m_wndSplit.CreateView(1, 0, RUNTIME_CLASS(CAttachedFileView), CSize(0, 0), pContext);
+	this->m_pAddrsV = (CAddressView*)m_split_address_mailedit.GetPane(0, 0);
+	this->m_pEditV = (CMailEditView*)m_split_address_mailedit.GetPane(1, 0);
+	this->m_pListV2 = (CAttachedFileView*)m_split_attachedfile_others.GetPane(1, 0);
 
-	this->m_pAddrsV = (CAddressView*)m_wndSplit1.GetPane(0, 0);
-	this->m_pEditV = (CMailEditView*)m_wndSplit1.GetPane(1, 0);
-	this->m_pListV2 = (CAttachedFileView*)m_wndSplit.GetPane(1, 0);
-
-	// CAddressView̃TCY
+	// adjust size of CAddressView
 	CSize size = this->m_pAddrsV->GetTotalSize();
-	this->m_wndSplit1.SetRowInfo(0, size.cy, size.cy);
+	this->m_split_address_mailedit.SetRowInfo(0, size.cy, size.cy);
 
 	// initialyzation
 	this->m_pAddrsV->OnInitialUpdate();
@@ -261,7 +326,7 @@ BOOL CDraftFrame::OnCreateClient(LPCREATESTRUCT lpcs, CCreateContext* pContext)
 		this->HideAttachedFileView(TRUE);
 	}
 
-	this->m_flag=TRUE;
+	this->m_flag = TRUE;
 
 	return TRUE;
 }
@@ -283,8 +348,7 @@ void CDraftFrame::OnAddFile()
 		AfxMessageBox("cannot open file");
 
 	// add item to attachedfileview.
-	this->m_pListV2->AddFile(path.GetBuffer(0));
-	path.ReleaseBuffer();
+	this->m_pListV2->AddFile(path);
 
 	// adjust someplace that is associated with gui.
 	this->HideAttachedFileView(FALSE);
@@ -295,8 +359,6 @@ void CDraftFrame::OnAddFile()
 void CDraftFrame::OnSize(UINT nType, int cx, int cy) 
 {
 	CFrameWnd::OnSize(nType, cx, cy);
-//	CPochyApp *app = (CPochyApp*)AfxGetApp();
-//	CMainFrame *mf = (CMainFrame *)app->m_pMainWnd;
 
 	if(this->m_flag)
 		this->ReArrangeSplit();
@@ -315,9 +377,9 @@ void CDraftFrame::OnAddress()
 	CStringArray cc;
 	CStringArray bcc;
 
-	g_cstr2cstra_ex(this->m_me.GetTo(),to, ",");
-	g_cstr2cstra_ex(this->m_me.GetCc(),cc, ",");
-	g_cstr2cstra_ex(this->m_me.GetBcc(),bcc, ",");
+	g_split_address(this->m_me.GetTo(), to, FALSE, FALSE);
+	g_split_address(this->m_me.GetCc(), cc, FALSE, FALSE);
+	g_split_address(this->m_me.GetBcc(), bcc, FALSE, FALSE);
 
 	int i;
 	for(i=0; i<to.GetSize(); i++){
@@ -491,7 +553,8 @@ void CDraftFrame::OnGpgEnc()
 		// preparation of executing process.
 		CStringArray list;
 		CString recipient;
-		for(int i=0; i<this->m_key_id_list.GetSize(); i++){
+		int max = this->m_key_id_list.GetSize();
+		for(int i=0; i<max; i++){
 			recipient = this->m_key_id_list[i];
 			list.Add(recipient);
 		}
@@ -537,7 +600,6 @@ void CDraftFrame::OnGpgExport()
 	CGpg gpg;
 
 	// selection of key.
-//	CPochyApp* app = (CPochyApp*)AfxGetApp();
 	CGpgKeyListDlg lkd;
 	if(lkd.DoModal()==IDOK && this->m_key_id_list.GetSize()){
 		// below may work under conditon that GpgKeyListDlg cannot accept multiple selection.
@@ -554,9 +616,11 @@ void CDraftFrame::OnClose()
 	if(m_send_dlg != NULL)
 		return;
 
-	if(!SaveToDraft(TRUE)){
-		this->SetForegroundWindow();
-		return;
+	if(m_pEditV->GetRichEditCtrl().GetModify() || m_pAddrsV->GetModify()){
+		if(!SaveToDraft(TRUE)){
+			this->SetForegroundWindow();
+			return;
+		}
 	}
 
 	CPochyApp *app = (CPochyApp*)AfxGetApp();
@@ -676,6 +740,7 @@ BOOL CDraftFrame::CreateToolbar()
 
 BOOL CDraftFrame::SaveToDraft(BOOL confirm)
 {
+	CWaitCursor wait_cursor; // turn cursor into hourglass
 	CPochyApp *app = (CPochyApp*)AfxGetApp();
 	CMainFrame *mf = (CMainFrame *)app->m_pMainWnd;
 	CSummaryView *sv = mf->m_pListV;
@@ -692,7 +757,7 @@ BOOL CDraftFrame::SaveToDraft(BOOL confirm)
 	m_me.SetSubject(m_pAddrsV->GetSubject());
 	m_me.SetReplyTo(m_pAddrsV->GetReplyTo());
 	CTime time = CTime::GetCurrentTime();
-	m_me.SetDate(time.Format("%d %b %Y %H:%M:%S ")+DEF_TIME_ZONE);
+	m_me.SetDate(time.Format("%d %b %Y %H:%M:%S ")+app->m_time_zone_offset);
 
 	// setting body.
 	if(m_me.GetMode() == ME_MODE_NONE)
@@ -760,7 +825,7 @@ void CDraftFrame::OnChangeTxtColorDraft()
 
 }
 
-BOOL CDraftFrame::OnToolbarDropDown(NMHDR *pNMHDR, LRESULT *plr)
+void CDraftFrame::OnToolbarDropDown(NMHDR *pNMHDR, LRESULT *plr)
 {
 	CWnd *pWnd;
 	UINT nID;
@@ -774,7 +839,7 @@ BOOL CDraftFrame::OnToolbarDropDown(NMHDR *pNMHDR, LRESULT *plr)
 		nID  = IDR_DRAFTFRAME_POPUP_GPG;
 		break;
 	default:
-		return TRUE;
+		return;
 	}
 
 	// load and display popup menu
@@ -789,7 +854,7 @@ BOOL CDraftFrame::OnToolbarDropDown(NMHDR *pNMHDR, LRESULT *plr)
 
 	pPopup->TrackPopupMenu( TPM_LEFTALIGN | TPM_LEFTBUTTON | TPM_VERTICAL, rc.left, rc.bottom, this, &rc);
 
-	return TRUE;
+	return;
 }
 
 BOOL CDraftFrame::PreCreateWindow(CREATESTRUCT& cs) 
@@ -830,13 +895,13 @@ void CDraftFrame::OnExtEditor()
 void CDraftFrame::ReArrangeSplit()
 {
 	CRect rect;
-	m_wndSplit.GetClientRect(&rect);
+	m_split_attachedfile_others.GetClientRect(&rect);
 	rect.NormalizeRect();
 	int height = rect.Height()-4/* may be width of frame */;
 	rect.SetRectEmpty();
 
-	m_wndSplit.SetRowInfo(0, height-HT_ATTACHED_HEIGHT, 0);
-	m_wndSplit.RecalcLayout();
+	m_split_attachedfile_others.SetRowInfo(0, height-HT_ATTACHED_HEIGHT, 0);
+	m_split_attachedfile_others.RecalcLayout();
 
 	this->Invalidate(FALSE);
 	this->UpdateWindow();
@@ -845,12 +910,12 @@ void CDraftFrame::ReArrangeSplit()
 void CDraftFrame::HideAttachedFileView(BOOL b)
 {
 	if(b && m_hide_attach == FALSE){
-		m_wndSplit.HideRow(1);
+		m_split_attachedfile_others.HideRow(1);
 		m_hide_attach = TRUE;
 		this->Invalidate(FALSE);
 		this->UpdateWindow();
 	}else if(!b && m_hide_attach == TRUE){
-		m_wndSplit.ShowRow();
+		m_split_attachedfile_others.ShowRow();
 		m_hide_attach = FALSE;
 		this->Invalidate(FALSE);
 		this->UpdateWindow();
@@ -963,3 +1028,18 @@ void CDraftFrame::LoadDefaultAccelerator()
 
 	m_acceleratorTable.CreateAcceleratorTable();
 }
+
+void CDraftFrame::OnSysCommand(UINT nID, LPARAM lParam) 
+{
+	CFrameWnd::OnSysCommand(nID, lParam);
+
+	CPochyApp *pPochyApp = (CPochyApp *)AfxGetApp();
+	if (pPochyApp != NULL)
+	{
+		CMainFrame *pMainFrame = (CMainFrame*)pPochyApp->m_pMainWnd;
+		if (pMainFrame != NULL)
+		{
+			pMainFrame->CallPluginCallback(GetSafeHwnd(), nID);
+		}
+	}
+}
