@@ -66,6 +66,7 @@ BEGIN_MESSAGE_MAP(CFolderView, CBitmapTreeView)
 	ON_COMMAND(ID_FOLDERVIEW_CLEAR_TRASH, OnPopupClearTrash)
 	ON_COMMAND(ID_NEXT_FOLDER, OnNextFolder)
 	ON_COMMAND(ID_PREV_FOLDER, OnPrevFolder)
+//	ON_WM_CAPTURECHANGED()
 	//}}AFX_MSG_MAP
 END_MESSAGE_MAP()
 
@@ -87,11 +88,10 @@ void CFolderView::OnDraw(CDC* pDC)
 		pDC->SelectObject(pTreeCtrl->GetFont());
 		pDC->SetTextColor(pTreeCtrl->GetTextColor());
 
-		HTREEITEM hRootTreeItem = pTreeCtrl->GetRootItem();
 		HTREEITEM hTreeItem = pTreeCtrl->GetFirstVisibleItem();
 		while (hTreeItem != NULL)
 		{
-			if (hTreeItem != hRootTreeItem)
+			if (WhatKind(hTreeItem) != FV_TOP)
 			{
 				CRect itemBoundsRect, itemTextRect;
 				if ((pTreeCtrl->GetItemRect(hTreeItem, &itemBoundsRect, FALSE) != 0) &&
@@ -189,7 +189,7 @@ void CFolderView::OnInitialUpdate()
 
 	// change style of view
 	SetWindowLong(hWnd, GWL_STYLE,
-		dwStyle|TVS_HASLINES/*|TVS_LINESATROOT*/|TVS_HASBUTTONS|TVS_EDITLABELS|TVS_SHOWSELALWAYS);
+		dwStyle|TVS_HASLINES|TVS_LINESATROOT|TVS_HASBUTTONS|TVS_EDITLABELS|TVS_SHOWSELALWAYS/*|TVS_SINGLEEXPAND*/);
 
 	// set color
 	COLORREF m_colorEdit;
@@ -206,18 +206,18 @@ void CFolderView::OnInitialUpdate()
 		app->GetProfileInt("FolderViewColor", "TxtColorB", DEF_TXT_COLOR_B));
 	tc.SetTextColor(m_colorEdit);
 
+	ConstructTree();
+
 	CMainFrame *mf = (CMainFrame*)this->GetParentFrame();
-	CString def_account = mf->m_pAcntV->GetCurrentAccountName();
-	if(!def_account.IsEmpty()){
-		ConstructTree(def_account);
-	}else{
-		mf->m_pAcntV->m_combo_account.GetLBText(0, def_account);
-		ConstructTree(def_account);
+	CAccountView* pAccountView = (CAccountView*)mf->m_pAcntV;
+	CString def_account = pAccountView->GetCurrentAccountName();
+	if (def_account.IsEmpty())
+	{
+		pAccountView->m_combo_account.GetLBText(0, def_account);
 	}
 
 	// select top item
-	HTREEITEM ti = tc.GetChildItem(tc.GetRootItem());
-	tc.SelectItem(ti);
+	SelectInbox(def_account);
 
 	// set background bmp
 //	CString strBackgroundFilePath = app->m_app_path + TREEVIEW_BACKGROUND_FILENAME;
@@ -232,48 +232,61 @@ void CFolderView::OnInitialUpdate()
 	SetBkImage(strBackgroundFilePath);
 }
 
+void CFolderView::ConstructTree()
+{
+	CWaitCursor wait_cursor; // turn cursor into sandglass	
+	CPochyApp* pApp = (CPochyApp*)::AfxGetApp();
+	CMainFrame* pMainFrame = (CMainFrame*)pApp->m_pMainWnd;
+	CAccountView* pAccountView = (CAccountView*)pMainFrame->m_pAcntV;
+	CTreeCtrl &tc = GetTreeCtrl();
+	tc.DeleteAllItems();
+
+	int nAccountCount = pAccountView->m_data.GetSize();
+	int nAccount;
+	for (nAccount = 0; nAccount < nAccountCount; nAccount++)
+	{
+		ConstructTree(pAccountView->m_data[nAccount].account_name);
+	}
+}
+
 void CFolderView::ConstructTree(CString account)
 {
-	CFileFind ff;
-	CStringArray DirArray;
-	CTreeCtrl& tc = GetTreeCtrl();
-	CPochyApp* app = (CPochyApp*)AfxGetApp();
-
-	tc.DeleteAllItems();
 	if(account.IsEmpty())
 		return;
 
+	CPochyApp* app = (CPochyApp*)AfxGetApp();
 	if(!g_is_there(app->m_app_path+"\\"+account+"\\account.ini"))
 		return;
 
 	AddUser(app->m_app_path + "\\" + account, account);
-	tc.Expand(tc.GetRootItem(), TVE_EXPAND);
 }
 
-void CFolderView::OnSelchanged(NMHDR* pNMHDR, LRESULT* pResult) 
+void CFolderView::OnSelchanged(NMHDR* /*pNMHDR*/, LRESULT* pResult) 
 {
-	NM_TREEVIEW* pNMTreeView = (NM_TREEVIEW*)pNMHDR;
+//	NM_TREEVIEW* pNMTreeView = (NM_TREEVIEW*)pNMHDR;
 	CTreeCtrl& tc = GetTreeCtrl();
 	CPochyApp* app = (CPochyApp*)AfxGetApp();
 	CMainFrame *mf = (CMainFrame*)app->m_pMainWnd;
 	CSummaryView *sv = mf->m_pListV;
 	CTextView *tv = mf->m_pTextV;
 	CHeaderView *hv = mf->m_pHeadV;
+	CAccountView *av = mf->m_pAcntV;
 
-	HTREEITEM ti = tc.GetSelectedItem();
-	CString current_account;
+	CString oldAccount = av->GetCurrentAccountName();
+	CString newAccount = GetSelectedItemAccountName();
+	if (oldAccount != newAccount)
+	{
+		av->SelectAccount(av->GetAccountNum(newAccount));
+	}
 
 	// each button(reply, transfer, header info) is invalidate
-/*	mf->m_button_reply = FALSE;
-	mf->m_button_transfer = FALSE;
-	mf->m_button_info = FALSE;*/
 	mf->UpdateButton2(FALSE);
 
 	// gpg button in toolbar is invalidate
 	mf->m_button_gpg_dec = FALSE;
 
-	CWaitCursor wait_cursor; // turn cursor into sandglass
 	// listview is displayed
+	HTREEITEM ti = tc.GetSelectedItem();
 	sv->SetItem(app->m_app_path + this->GetItemPath(ti));
 
 	// hide multipartview
@@ -283,11 +296,8 @@ void CFolderView::OnSelchanged(NMHDR* pNMHDR, LRESULT* pResult)
 	tv->Clear();
 	hv->Clear();
 
-	// change document name to current mailbox name
-    CString title;
-    CString account = mf->m_pAcntV->GetCurrentAccountName();
-    title.Format("%s - %s", account, "pochy");
-    mf->SetWindowText(title);
+	// call plugin
+	app->m_pluginManager.OnFolderChanged(GetSelectedItemName());
 
 	*pResult = 0;
 }
@@ -310,7 +320,7 @@ void CFolderView::AddSubItem(HTREEITEM Item)
 			while(b_Find){
 				b_Find = ff.FindNextFile();
 				if(ff.IsDirectory() && !ff.IsDots())
-					treeCtrl.SetItemData(treeCtrl.InsertItem(ff.GetFileName().GetBuffer(0), 0, 0, subItem, TVI_LAST), FV_OTHER);
+					treeCtrl.SetItemData(treeCtrl.InsertItem(ff.GetFileName(), 0, 0, subItem, TVI_LAST), FV_OTHER);
 			}
 		}
 		subItem = treeCtrl.GetNextSiblingItem(subItem);
@@ -323,7 +333,6 @@ void CFolderView::OnItemexpanded(NMHDR* pNMHDR, LRESULT* pResult)
 	CString path;
 	CPochyApp *app = (CPochyApp *)AfxGetApp();
 	NM_TREEVIEW* pNMTreeView = (NM_TREEVIEW*)pNMHDR;
-
 	CWaitCursor wait_cursor; // turn cursor into sandglass
 
 	ti = pNMTreeView->itemNew.hItem;
@@ -376,10 +385,10 @@ CString CFolderView::GetTopItemName(HTREEITEM ti)
 	return name;
 }
 
-void CFolderView::OnSelchanging(NMHDR* pNMHDR, LRESULT* pResult) 
+void CFolderView::OnSelchanging(NMHDR* /*pNMHDR*/, LRESULT* pResult) 
 {
 
-	NM_TREEVIEW* pNMTreeView = (NM_TREEVIEW*)pNMHDR;
+//	NM_TREEVIEW* pNMTreeView = (NM_TREEVIEW*)pNMHDR;
 	// save width of column into ini file
 	CPochyApp *app = (CPochyApp *)AfxGetApp();
 	CMainFrame *mf = (CMainFrame*)app->m_pMainWnd;
@@ -390,7 +399,7 @@ void CFolderView::OnSelchanging(NMHDR* pNMHDR, LRESULT* pResult)
 
 	for(i = 0; i < 4; i++){
 		num.Format("%d", i);
-		app->WriteProfileInt("SummaryViewColumn", num.GetBuffer(0), listView->GetListCtrl().GetColumnWidth(i));
+		app->WriteProfileInt("SummaryViewColumn", num, listView->GetListCtrl().GetColumnWidth(i));
 	}
 	*pResult = 0;
 }
@@ -406,7 +415,7 @@ void CFolderView::AddUser(CString path, CString user)
 	CFileFind ff;
 	CSortStringArray DirArray;
 	CTreeCtrl& tc = GetTreeCtrl();
-	HTREEITEM hItem = tc.InsertItem(user, 3, 3, TVI_ROOT, TVI_FIRST);
+	HTREEITEM hItem = tc.InsertItem(user, 3, 3, TVI_ROOT, TVI_LAST);
 	tc.SetItemData(hItem, FV_TOP);
 
 	BOOL b = ff.FindFile(path + "\\*.*");
@@ -447,8 +456,11 @@ void CFolderView::AddUser(CString path, CString user)
 	tc.SetItemData(tc.InsertItem(draft, 4, 5, hItem, TVI_LAST), FV_DRAFT);
 	tc.SetItemData(tc.InsertItem(trash, 2, 2, hItem, TVI_LAST), FV_TRASH);
 
-	for(int i=0; i <= DirArray.GetUpperBound(); i++)
+	int max = DirArray.GetUpperBound();
+	for(int i=0; i <= max; i++)
 		tc.SetItemData(tc.InsertItem(DirArray.GetAt(i), 0, 1, hItem, TVI_LAST), FV_OTHER);
+
+	tc.Expand(hItem, TVE_EXPAND);
 }
 
 void CFolderView::RemoveUser(CString user)
@@ -584,7 +596,6 @@ void CFolderView::OnBegindrag(NMHDR* pNMHDR, LRESULT* pResult)
 
 void CFolderView::OnMouseMove(UINT nFlags, CPoint point) 
 {
-	CPochyApp* app = (CPochyApp*)AfxGetApp();
 	HTREEITEM	hitem;
 	UINT		flags;
 
@@ -701,8 +712,15 @@ void CFolderView::OnLButtonUp(UINT nFlags, CPoint point)
 
 int CFolderView::WhatKind(HTREEITEM hItem)
 {
-	CTreeCtrl& treeCtrl = GetTreeCtrl();
-	return treeCtrl.GetItemData(hItem);
+	if (hItem != NULL)
+	{
+		CTreeCtrl& treeCtrl = GetTreeCtrl();
+		return treeCtrl.GetItemData(hItem);
+	}
+	else
+	{
+		return FV_OTHER;
+	}
 }
 
 int CFolderView::GetSelectedItemKind()
@@ -732,7 +750,7 @@ BOOL CFolderView::DeleteFolder(HTREEITEM ti)
 	return FALSE;
 }
 
-void CFolderView::OnRclick(NMHDR* pNMHDR, LRESULT* pResult) 
+void CFolderView::OnRclick(NMHDR* /*pNMHDR*/, LRESULT* pResult) 
 {
 	const MSG* msg = GetCurrentMessage();
 	CPoint pt1 = msg->pt;
@@ -784,6 +802,12 @@ void CFolderView::OnRclick(NMHDR* pNMHDR, LRESULT* pResult)
 		// validate
 		menu.EnableMenuItem(ID_FOLDERVIEW_RENAME, MF_ENABLED);
 
+	CPochyApp* pPochyApp = (CPochyApp*)::AfxGetApp();
+	if (pPochyApp != NULL)
+	{
+		pPochyApp->m_pluginManager.OnInitMenu(menu.GetSubMenu(0)->GetSafeHmenu(), POCHY_MENU_FOLDER_VIEW);
+	}
+
 	CMenu *pPopup = menu.GetSubMenu(0);
 	pPopup->TrackPopupMenu(TPM_LEFTALIGN | TPM_RIGHTBUTTON |TPM_LEFTBUTTON, (int)pt2.x, (int)pt2.y, this);
 
@@ -797,14 +821,14 @@ void CFolderView::OnPopupDel()
 	DeleteFolder(fv.GetSelectedItem());
 }
 
-BOOL CFolderView::AddFolder(HTREEITEM parent_ti)
+BOOL CFolderView::AddFolder(HTREEITEM /*parent_ti*/)
 {
 	return TRUE;
 }
 
-void CFolderView::OnEndlabeledit(NMHDR* pNMHDR, LRESULT* pResult) 
+void CFolderView::OnEndlabeledit(NMHDR* /*pNMHDR*/, LRESULT* pResult) 
 {
-	TV_DISPINFO* pTVDispInfo = (TV_DISPINFO*)pNMHDR;
+//	TV_DISPINFO* pTVDispInfo = (TV_DISPINFO*)pNMHDR;
 	CPochyApp *app = (CPochyApp *)AfxGetApp();
 	CMainFrame *mf = (CMainFrame*)app->m_pMainWnd;
 	CString name;
@@ -880,9 +904,9 @@ void CFolderView::OnPopupAdd()
 	GetTreeCtrl().SelectItem(hItem2);
 }
 
-void CFolderView::OnBeginlabeledit(NMHDR* pNMHDR, LRESULT* pResult) 
+void CFolderView::OnBeginlabeledit(NMHDR* /*pNMHDR*/, LRESULT* pResult) 
 {
-	TV_DISPINFO* pTVDispInfo = (TV_DISPINFO*)pNMHDR;
+//	TV_DISPINFO* pTVDispInfo = (TV_DISPINFO*)pNMHDR;
 
 	m_current_edit_item_name = GetTreeCtrl().GetItemText(GetTreeCtrl().GetSelectedItem());
 
@@ -896,11 +920,7 @@ void CFolderView::OnBeginlabeledit(NMHDR* pNMHDR, LRESULT* pResult)
 
 void CFolderView::OnPopupRebuild() 
 {
-	CPochyApp *app = (CPochyApp *)AfxGetApp();
-	CMainFrame *mf = (CMainFrame*)app->m_pMainWnd;
-	CTreeCtrl &tc = GetTreeCtrl();
-	tc.DeleteAllItems();
-	ConstructTree(mf->m_pAcntV->GetCurrentAccountName());
+	ConstructTree();
 }
 
 void CFolderView::OnSize(UINT nType, int cx, int cy) 
@@ -986,12 +1006,12 @@ void CFolderView::OnPrevFolder()
 
 // path ɑtH_[I
 // Ă珇ɊJ
-void CFolderView::SelectFolder(const std::string &path)
+void CFolderView::SelectFolder(const CString &path)
 {
-	if (path != _T(""))
+	if (!path.IsEmpty())
 	{
 		CPochyApp* pApp = (CPochyApp*)::AfxGetApp();
-		std::string shortPath = path.substr(pApp->m_app_path.GetLength() + 1);
+		std::string shortPath = path.Right(path.GetLength() - pApp->m_app_path.GetLength() - 1);
 		std::vector<std::string> shortPathList;
 
 		std::string str;
@@ -1006,29 +1026,43 @@ void CFolderView::SelectFolder(const std::string &path)
 
 		// [g}Ɍ
 		CTreeCtrl& treeCtrl = GetTreeCtrl();
-		HTREEITEM hTreeItem = treeCtrl.GetRootItem();
-		std::string targetPath;
-		HTREEITEM hTargetTree = NULL;
-//		SetRedraw(FALSE);
-		int i;
-		for (i = 0; i < shortPathList.size(); i++)
+		HTREEITEM hTreeRootItem = treeCtrl.GetRootItem();
+		HTREEITEM hTreeTargetItem = NULL;
+		while (hTreeRootItem != NULL)
 		{
-			targetPath += _T("\\") + shortPathList[i];
-			hTargetTree = FindFolder(hTreeItem, targetPath);
-			if (hTargetTree != NULL)
+			HTREEITEM hTreeItem = hTreeRootItem;
+			hTreeTargetItem = NULL;
+			std::string targetPath;
+//			SetRedraw(FALSE);
+			UINT i;
+			for (i = 0; i < shortPathList.size(); i++)
 			{
-				if (i != shortPathList.size() - 1)
+				targetPath += _T("\\") + shortPathList[i];
+				hTreeTargetItem = FindFolder(hTreeItem, targetPath);
+				if (hTreeTargetItem != NULL)
 				{
-					// ̂rȂ}J
-					treeCtrl.Expand(hTargetTree, TVE_EXPAND);
+					if (i != shortPathList.size() - 1)
+					{
+						// ̂rȂ}J
+						treeCtrl.Expand(hTreeTargetItem, TVE_EXPAND);
+					}
+					hTreeItem = hTreeTargetItem;
 				}
-				hTreeItem = hTargetTree;
 			}
+//			SetRedraw(TRUE);
+
+			if (hTreeTargetItem != NULL)
+			{
+				break;
+			}
+			// ̃[gc[Ώۂɂ
+			hTreeRootItem = treeCtrl.GetNextItem(hTreeRootItem, TVGN_NEXT);
 		}
-//		SetRedraw(TRUE);
-		if (hTargetTree != NULL)
+
+		if (hTreeTargetItem != NULL)
 		{
-			treeCtrl.SelectItem(hTargetTree);
+			treeCtrl.SelectItem(hTreeTargetItem);
+			treeCtrl.Invalidate(FALSE);
 		}
 	}
 }
@@ -1071,10 +1105,67 @@ HTREEITEM CFolderView::FindFolder(HTREEITEM hTreeItem, const std::string &path)
 	return hResult;
 }
 
-int CFolderView::GetCurrentItemKind()
-{
-	CTreeCtrl& tc = GetTreeCtrl();
-	HTREEITEM ti = tc.GetSelectedItem();
 
-	return WhatKind(ti);
+BOOL CFolderView::OnCommand(WPARAM wParam, LPARAM lParam) 
+{
+	CPochyApp *pPochyApp = (CPochyApp *)AfxGetApp();
+	if (pPochyApp != NULL)
+	{
+		CMainFrame *pMainFrame = (CMainFrame*)pPochyApp->m_pMainWnd;
+		if (pMainFrame != NULL)
+		{
+			pMainFrame->CallPluginCallback(this->GetSafeHwnd(), LOWORD(wParam));
+		}
+	}
+
+	return CBitmapTreeView::OnCommand(wParam, lParam);
 }
+
+// c[ACȅAJEgOԂ
+const CString CFolderView::GetItemAccountName(const HTREEITEM hTreeItem)
+{
+	CTreeCtrl& treeCtrl = GetTreeCtrl();
+	CString accountName;
+	HTREEITEM hItem = hTreeItem;
+	while (hItem != NULL && WhatKind(hItem) != FV_TOP)
+	{
+		hItem = treeCtrl.GetParentItem(hItem);
+	}
+	if (hItem != NULL)
+	{
+		accountName = treeCtrl.GetItemText(hItem);
+	}
+	return accountName;
+}
+
+// IĂtH_[̃AJEgԂ
+const CString CFolderView::GetSelectedItemAccountName()
+{
+	CTreeCtrl& treeCtrl = GetTreeCtrl();
+	HTREEITEM hTreeItem = treeCtrl.GetSelectedItem();
+
+	return GetItemAccountName(hTreeItem);
+}
+
+void CFolderView::SelectInbox(const CString &account)
+{
+	CPochyApp *pPochyApp = (CPochyApp *)AfxGetApp();
+
+	if (!account.IsEmpty())
+	{
+		SelectFolder(pPochyApp->m_app_path + _T('\\') + account + _T("\\inbox"));
+	}
+}
+/*
+void CFolderView::OnCaptureChanged(CWnd *pWnd) 
+{
+	if( m_bLDragging == TRUE ){
+		m_bLDragging = FALSE;
+		CImageList::DragLeave(this);
+		CImageList::EndDrag();
+		ReleaseCapture();
+	}
+
+	CBitmapTreeView::OnCaptureChanged(pWnd);
+}
+*/
\ No newline at end of file
