@@ -120,10 +120,11 @@ void CGpgDlg::ReDraw()
 	int i;
 	SLISTSTACK list;
 	CStringArray bodya;
-	g_cstr2cstra(body, bodya, "\r\n");
+	g_string2cstringarray(body, bodya, "\r\n", FALSE);
 
 	m_keylist.RemoveAll();
-	for(i=0;i<bodya.GetSize();i++){
+	int max = bodya.GetSize();
+	for(i=0; i<max; i++){
 		CString tmps = bodya.GetAt(i);
 		if(tmps.Find("pub")==0 || tmps.Find("sub")==0 || tmps.Find("sec")==0 || tmps.Find("ssb")==0){
 			Str2Sliststack(tmps,list);
@@ -134,7 +135,8 @@ void CGpgDlg::ReDraw()
 	TruncateSubKey();
 
 	m_lc.DeleteAllItems();
-	for(i=0;i<m_keylist.GetSize();i++)
+	max = m_keylist.GetSize();
+	for(i=0; i<max; i++)
 		m_lc.InsertItem(m_lc.GetItemCount(),m_keylist.GetAt(i).m_str4);
 
 	// Ԃ̐ݒ
@@ -175,7 +177,8 @@ void CGpgDlg::TranslateKeycode(SLISTSTACK& ls)
 
 void CGpgDlg::TruncateSubKey()
 {
-	for(int i=0;i<m_keylist.GetSize();i++){
+	int max = m_keylist.GetSize();
+	for(int i=0; i<max; i++){
 		if(m_keylist.GetAt(i).m_str1 == "sec" || m_keylist.GetAt(i).m_str1 == "ssb"){
 			for(int j=0;j<m_keylist.GetSize();j++){
 				if(m_keylist.GetAt(j).m_str5 == m_keylist.GetAt(i).m_str5 && (m_keylist.GetAt(j).m_str1 == "pub" || m_keylist.GetAt(j).m_str1 == "sub")){
@@ -184,7 +187,7 @@ void CGpgDlg::TruncateSubKey()
 			}
 		}
 	}
-	for(i=0;i<m_keylist.GetSize();i++){
+	for(i=0; i<m_keylist.GetSize(); i++){
 		if(m_keylist.GetAt(i).m_str1 == "sub"){
 			for(int j=0;j<m_keylist.GetSize();j++){
 				if(m_keylist.GetAt(j).m_str8 == m_keylist.GetAt(i).m_str8 && m_keylist.GetAt(j).m_str1 == "pub"){
@@ -195,11 +198,12 @@ void CGpgDlg::TruncateSubKey()
 			i--;
 		}
 	}
-	for(i=0;i<m_keylist.GetSize();i++)
+	max = m_keylist.GetSize();
+	for(i=0; i<max; i++)
 		TRACE("ID=%s\n",m_keylist.GetAt(i).m_str8);
-	for(i=0;i<m_keylist.GetSize();i++){
+	for(i=0; i<m_keylist.GetSize(); i++){
 		if(m_keylist.GetAt(i).m_str1 == "ssb"){
-			for(int j=0;j<m_keylist.GetSize();j++){
+			for(int j=0; j<m_keylist.GetSize(); j++){
 				if(m_keylist.GetAt(j).m_str8 == m_keylist.GetAt(i).m_str8 && m_keylist.GetAt(j).m_str1 == "sec")
 					m_keylist[j].m_str4 += "/"+m_keylist.GetAt(i).m_str4;
 			}
@@ -215,11 +219,10 @@ void CGpgDlg::Str2Sliststack(CString& str,SLISTSTACK& ls)
 	CStringArray stra;
 	CString* pstr;
 	CString buf;
-	g_cstr2cstra(str,stra,":");
+	g_string2cstringarray(str, stra,":", FALSE);
 	for(i=0;i<stra.GetSize()-1;i++){
 		pstr = &ls.m_str1 + i;
 		buf = stra.GetAt(i);
-		buf.TrimRight(":");
 		*pstr = buf;
 	}
 }
@@ -448,6 +451,6 @@ void CGpgDlg::OnGpgExport()
 			key = gpg.ExportKey(g_ma(m_keylist[si].m_str10));
 		if(m_keylist[si].m_str1 == "sec")
 			key = gpg.ExportSecKey(g_ma(m_keylist[si].m_str10));
-		g_cstring2file(key, path);
+		g_string2file(key, path);
 	}
 }
