@@ -177,11 +177,11 @@ void CGpgKeyListDlg::Str2Sliststack(CString& str,SLISTSTACK& ls)
 	CStringArray stra;
 	CString* pstr;
 	CString buf;
-	g_cstr2cstra(str,stra,":");
+	g_string2cstringarray(str, stra,":", FALSE);
 	for(i=0;i<stra.GetSize()-1;i++){
 		pstr = &ls.m_str1 + i;
 		buf = stra.GetAt(i);
-		buf.TrimRight(":");
+//		buf.TrimRight(":");
 		*pstr = buf;
 	}
 }
@@ -260,7 +260,7 @@ void CGpgKeyListDlg::ReDraw()
 	int i;
 	SLISTSTACK list;
 	CStringArray bodya;
-	g_cstr2cstra(body, bodya, "\r\n");
+	g_string2cstringarray(body, bodya, "\r\n", FALSE);
 
 	m_keylist.RemoveAll();
 	for(i=0;i<bodya.GetSize();i++){
