@@ -37,11 +37,11 @@ CHeaderInfo::CHeaderInfo(CString buf)
 	// if whole mail is handed over, only header part is picked up.
 	switch(point = buf.Find("\r\n\r\n")){
 		case -1:
-			g_cstr2cstra(buf, m_undecoded_header, "\r\n");
+			g_string2cstringarray(buf, m_undecoded_header, "\r\n", TRUE);
 			break;
 		default:
 			buf = buf.Left(point + strlen("\r\n"));
-			g_cstr2cstra(buf, m_undecoded_header, "\r\n");
+			g_string2cstringarray(buf, m_undecoded_header, "\r\n", TRUE);
 			break;
 	}
 	Decode();	// wb_𐮂蕶R[hϊs
@@ -63,15 +63,16 @@ BOOL CHeaderInfo::DoIt(CStringArray &buf)
 	// initialyze
 	InitMemVal();
 
-	int n = 0;
+	int n;
+	int max;
 	CString message;
 
 	// if whole mail is handed over, only header part is picked up.
-	while(n < buf.GetSize()){
+	max = buf.GetSize();
+	for(n=0; n<max; n++){
 		if(buf.GetAt(n) == "\x0D\x0A")
 			break;
 		m_undecoded_header.Add(buf.GetAt(n));
-		n++;
 	}
 	Decode();	// wb_𐮂蕶R[hϊs
 	Analyze();	// wb_𕪐͂āAKvȏoɊi[
@@ -85,118 +86,98 @@ BOOL CHeaderInfo::DoIt(CStringArray &buf)
 // wb_𕪐͂ĕKvȏoϐɊi[
 void CHeaderInfo::Analyze()
 {
-	regex_t reg;
+	CString header_name;
 	int pos;
-	CString field;
-	for(int i = 0; i < m_decoded_header.GetSize(); i++){
+	int max = m_decoded_header.GetSize();
+	for(int i = 0; i < max; i++){
 		pos = m_decoded_header[i].Find(":");
 		if(pos == -1)
 			continue;
-		field = m_decoded_header[i].Left(pos);
-		regcomp(&reg, field, REG_EXTENDED | REG_NEWLINE | REG_ICASE);
+		header_name = m_decoded_header[i].Left(pos);
+		header_name.MakeLower();
 
-		if(!regexec(&reg, "subject", 0, NULL, 0)){
-			regfree(&reg);
+		if(strcmp("subject", header_name) == 0){
 			m_subject = m_decoded_header[i].Mid(strlen("Subject:"));
-			g_cstr_chop(m_subject);
+			g_cstring_chop(m_subject);
 			continue;
-		}
-		if(!regexec(&reg, "cc", 0, NULL, 0)){
-			regfree(&reg);
+		}else if(strcmp("cc", header_name) == 0){
 			m_cc = m_decoded_header[i].Mid(strlen("cc:"));
-			g_cstr_chop(m_cc);
+			g_cstring_chop(m_cc);
 			continue;
-		}
-		if(!regexec(&reg, "bcc", 0, NULL, 0)){
-			regfree(&reg);
+		}else if(strcmp("bcc", header_name) == 0){
 			m_bcc = m_decoded_header[i].Mid(strlen("bcc:"));
-			g_cstr_chop(m_bcc);
+			g_cstring_chop(m_bcc);
 			continue;
-		}
-		if(!regexec(&reg, "from", 0, NULL, 0)){
-			regfree(&reg);
+		}else if(strcmp("from", header_name) == 0){
 			m_from = m_decoded_header[i].Mid(strlen("from:"));
-			g_cstr_chop(m_from);
+			g_cstring_chop(m_from);
 			continue;
-		}
-		if(!regexec(&reg, "to", 0, NULL, 0)){
-			regfree(&reg);
+		}else if(strcmp("to", header_name) == 0){
 			m_to = m_decoded_header[i].Mid(strlen("to:"));
-			g_cstr_chop(m_to);
+			g_cstring_chop(m_to);
 			continue;
-		}
-		if(!regexec(&reg, "x-mailer", 0, NULL, 0)){
-			regfree(&reg);
+		}else if(strcmp("x-mailer", header_name) == 0){
 			m_xmailer = m_decoded_header[i].Mid(strlen("x-mailer:"));
-			g_cstr_chop(m_xmailer);
+			g_cstring_chop(m_xmailer);
 			continue;
-		}
-		if(!regexec(&reg, "reply-to", 0, NULL, 0)){
-			regfree(&reg);
+		}else if(strcmp("reply-to", header_name) == 0){
 			m_replyto = m_decoded_header[i].Mid(strlen("reply-to:"));
-			g_cstr_chop(m_replyto);
+			g_cstring_chop(m_replyto);
 			continue;
-		}
-		if(!regexec(&reg, "date", 0, NULL, 0)){
-			regfree(&reg);
-			m_date = ReformDate(m_decoded_header[i]);
+		}else if(strcmp("date", header_name) == 0){
+			m_date = m_decoded_header[i].Mid(strlen("Date:"));
+			g_cstring_chop(m_date);
 			continue;
-		}
-		if(!regexec(&reg, "content-transfer-encoding", 0, NULL, 0)){
-			regfree(&reg);
+		}else if(strcmp("content-transfer-encoding", header_name) == 0){
 			CString cte;
 			m_cte = m_decoded_header[i];
-			m_cte.TrimRight("\r\n");
+			g_cstring_chop(m_cte);
 			cte = m_decoded_header[i].Mid(strlen("Content-Transfer-Encoding:"));
-			g_cstr_chop(cte);
-			if(g_cstr_compare(cte.GetBuffer(0), "7bit"))
+			cte.MakeLower();
+			g_cstring_chop(cte);
+			if(strcmp("7bit", cte) == 0)
 				m_enc = SEVEN_BIT;
-			if(g_cstr_compare(cte.GetBuffer(0), "8bit"))
+			else if(strcmp("8bit", cte) == 0)
 				m_enc = EIGHT_BIT;
-			if(g_cstr_compare(cte.GetBuffer(0), "bin"))
+			else if(strcmp("bin", cte) == 0)
 				m_enc = BIN;
-			if(g_cstr_compare(cte.GetBuffer(0), "base64"))
+			else if(strcmp("base64", cte) == 0)
 				m_enc = BASE64;
-			if(g_cstr_compare(cte.GetBuffer(0), "x-gzip64")) // x-gzip64 is temporarily treat as base64 (zlib.dll is necessary)
+			else if(strcmp("x-gzip64", cte) == 0) // x-gzip64 is temporarily treat as base64 (zlib.dll is necessary)
 				m_enc = BASE64;
-			if(g_cstr_compare(cte.GetBuffer(0), "quoted-printable"))
+			else if(strcmp("quoted-printable", cte) == 0)
 				m_enc = QUOTED_PRINTABLE;
 			continue;
-		}
-		if(!regexec(&reg, "message-id", 0, NULL, 0)){
-			regfree(&reg);
+		}else if(strcmp("message-id", header_name) == 0){
 			m_msg_id = m_decoded_header[i].Mid(strlen("Message-ID:"));
-			g_cstr_chop(m_msg_id);
+			g_cstring_chop(m_msg_id);
 			continue;
-		}
-		if(!regexec(&reg, "in-reply-to", 0, NULL, 0)){
-			regfree(&reg);
+		}else if(strcmp("in-reply-to", header_name) == 0){
 			m_in_reply_to = m_decoded_header[i].Mid(strlen("In-Reply-To:"));
-			g_cstr_chop(m_in_reply_to);
+			g_cstring_chop(m_in_reply_to);
 			continue;
-		}
-		if(!regexec(&reg, "content-type", 0, NULL, 0)){
-			regfree(&reg);
+		}else if(strcmp("content-type", header_name) == 0){
 			m_ct = m_decoded_header[i];
-			g_cstr_chop(m_ct);
+			g_cstring_chop(m_ct);
 			AnalyzeCT();
 			continue;
-		}
-		if(!regexec(&reg, "content-disposition", 0, NULL, 0)){
-			regfree(&reg);
+		}else if(strcmp("content-disposition", header_name) == 0){
 			m_cd = m_decoded_header[i];
-			g_cstr_chop(m_cd);
+			g_cstring_chop(m_cd);
 			AnalyzeCD();
 			continue;
+		}else if(strcmp("x-popfile-link", header_name) == 0){
+			m_popfile_link = m_decoded_header[i].Mid(strlen("X-POPFile-Link:"));
+			g_cstring_chop(m_popfile_link);
+			continue;
 		}
-		regfree(&reg);
 	}
 	/* there is no Content-Type, below is applied
-	Content-Type: Text/Plain; charset=US-ASCII
+	Content-Type: text/plain; charset=US-ASCII
 	Content-Transfer-Encoding: 7bit 
 	*/
 	if(m_type.IsEmpty())
-		m_type = "Text/Plain";
+		m_type = "text/plain";
 	if(m_charset.IsEmpty())
 		m_charset = "US-ASCII ";
 	// m_cte is already set as 0(7bit) in InitMemVal()
@@ -206,7 +187,7 @@ CString CHeaderInfo::GetAllDecoded()
 {
 	CString buf;
 
-	g_cstra2cstr(m_decoded_header, buf, g_cstra_getsize(m_decoded_header));
+	g_cstringarray2cstring(m_decoded_header, buf);
 	return buf;
 }
 
@@ -214,7 +195,7 @@ CString CHeaderInfo::GetAllUnDecoded()
 {
 	CString buf;
 
-	g_cstra2cstr(m_undecoded_header, buf, g_cstra_getsize(m_undecoded_header));
+	g_cstringarray2cstring(m_undecoded_header, buf);
 	return buf;
 }
 
@@ -227,7 +208,8 @@ void CHeaderInfo::GetAllUnDecoded(CStringArray &header)
 CString CHeaderInfo::GetOneLine(LPCTSTR key)
 {
 	CString buf;
-	int n = 0;
+	int n;
+	int max;
 
 	// prepare for regex
 	regex_t reg;
@@ -239,17 +221,14 @@ CString CHeaderInfo::GetOneLine(LPCTSTR key)
 
 	regcomp(&reg, r, REG_EXTENDED | REG_NEWLINE | REG_ICASE);
 
-	while(n < m_decoded_header.GetSize()){
+	max = m_decoded_header.GetSize();
+	for(n=0; n<max; n++){
 		buf = m_decoded_header.GetAt(n);
-
-		if(0 == regexec(&reg, buf.GetBuffer(0), 1, pmatch, 0)){
+		if(0 == regexec(&reg, buf, 1, pmatch, 0)){
 			delete[] r;
-			buf.ReleaseBuffer();
 			regfree(&reg);
 			return buf;
 		}
-		buf.ReleaseBuffer();
-		n++;
 	}
 
 	regfree(&reg);
@@ -264,12 +243,12 @@ void CHeaderInfo::RemoveFoldingWhiteSpace(CStringArray *header)
 
 	CString cline;
 	CString pline;
-	int n = 0;
+	int n;
 
 	cline.Empty();
 	pline.Empty();
 
-	while(n < header->GetSize()){
+	for(n=0; n<header->GetSize(); n++){
 		if(header->GetAt(n).Find(" ") == 0){
 			while(1){
 				if(n == header->GetSize() || header->GetAt(n).Find(" ") != 0) break;						
@@ -279,16 +258,14 @@ void CHeaderInfo::RemoveFoldingWhiteSpace(CStringArray *header)
 				pline = header->GetAt(n-1);
 				pline.TrimRight("\r\n");
 				pline += cline;
-				header->SetAt(n-1, pline.GetBuffer(0));
+				header->SetAt(n-1, pline);
 				header->RemoveAt(n, 1);
 				pline.ReleaseBuffer();
 			}
 		}
-		n++;
 	}
 
-	n = 0;
-	while(n < header->GetSize()){
+	for(n=0; n<header->GetSize(); n++){
 		if(header->GetAt(n).Find("\t") == 0){
 			while(1){
 				if(n == header->GetSize() || header->GetAt(n).Find("\t") != 0) break;						
@@ -298,12 +275,11 @@ void CHeaderInfo::RemoveFoldingWhiteSpace(CStringArray *header)
 				pline = header->GetAt(n-1);
 				pline.TrimRight("\r\n");
 				pline += cline;
-				header->SetAt(n-1, pline.GetBuffer(0));
+				header->SetAt(n-1, pline);
 				header->RemoveAt(n, 1);
 				pline.ReleaseBuffer();
 			}
 		}
-		n++;
 	}
 
 }
@@ -322,8 +298,8 @@ void CHeaderInfo::Decode()
 	CString encode_type;	// B(base64) / Q(quoted-printable)
 	CString char_type;		// ISO-2022-JP and so on
 	CString char_encoded;	// part of encode
-	int len;
-	int n = 0;
+	int n;
+	int max;
 	CStringArray header;
 
 	// initialyze and copy
@@ -336,7 +312,8 @@ void CHeaderInfo::Decode()
 	// linear white space
 	RemoveLinearWhiteSpace(&header);
 
-	while(n < header.GetSize()){
+	max = header.GetSize();
+	for(n=0; n<max; n++){
 		buf = header.GetAt(n);
 		temp1.Empty();
 		temp2.Empty();
@@ -357,29 +334,22 @@ void CHeaderInfo::Decode()
 			char_encoded	=	buf.Mid(pmatch[3].rm_so, pmatch[3].rm_eo-pmatch[3].rm_so);
 
 			if(encode_type == "B" || encode_type == "b"){
-				len = from64tobits(temp2.GetBuffer(char_encoded.GetLength()), char_encoded.GetBuffer(0), char_encoded.GetLength());
-				temp2.ReleaseBuffer(len);
-				char_encoded.ReleaseBuffer();
+				g_decode_base64(char_encoded, temp2);
 				temp1 += temp2;
 				temp2.Empty();
-			}
-
-			if(encode_type == "Q" || encode_type == "q"){
+			}else if(encode_type == "Q" || encode_type == "q"){
 				char_encoded.Replace("_", " ");
-				len = fromQPtobits(temp2.GetBuffer(char_encoded.GetLength()), char_encoded.GetBuffer(0), char_encoded.GetLength());
-				temp2.ReleaseBuffer(len);
-				char_encoded.ReleaseBuffer();
+				g_decode_qp(char_encoded, temp2);
 				temp1 += temp2;
 				temp2.Empty();
 			}
-			temp1		+=	buf.Mid(pmatch[0].rm_eo);
-			buf			=	temp1;
+			temp1 += buf.Mid(pmatch[0].rm_eo);
+			buf = temp1;
 		}
 		// convert char code
 		CCodeConvert cc(buf);
 		buf = cc.ToSjis();
 		m_decoded_header.Add(buf);
-		n++;
 	}
 	regfree(&reg);
 
@@ -405,7 +375,6 @@ CString CHeaderInfo::GetBcc()
 	return m_bcc;
 }
 
-
 CString CHeaderInfo::GetDate()
 {
 	return m_date;
@@ -480,9 +449,9 @@ CString CHeaderInfo::GetProtocol()
 	return m_protocol;
 }
 
-CString CHeaderInfo::GetXattachment()
+CString CHeaderInfo::GetPopfileLink()
 {
-	return m_xattachment;
+	return m_popfile_link;
 }
 
 BOOL CHeaderInfo::IsMultipart()
@@ -492,90 +461,6 @@ BOOL CHeaderInfo::IsMultipart()
 	return FALSE;
 }
 
-CString CHeaderInfo::ReformDate(CString buf)
-{
-	CString temp;
-	CString day;
-	CString month;
-	CString year;
-	CString hour;
-	CString minute;
-	CString second;
-	CString zone;
-
-	regex_t reg; // for regex
-	regmatch_t pmatch[10]; // result of regexec is put into this
-
-	char *regex = "Date:[ \t]*([a-zA-Z]+)*,* *([0-9]+) +([a-zA-Z]+) +([0-9]+) +([0-9]+):([0-9]+):*([0-9]*) +([+-0-9a-zA-Z]*)";
-//		Date:     Mon, 3 Feb 2003 00:00:43 -0600
-//		Date: Sat, 29 Mar 2003 05:01:48 +0900
-	regcomp(&reg, regex, REG_EXTENDED | REG_NEWLINE | REG_ICASE);
-	if(0 == regexec(&reg, buf, 9, pmatch, 0)){
-		year = buf.Mid(pmatch[4].rm_so, pmatch[4].rm_eo-pmatch[4].rm_so);
-		month = buf.Mid(pmatch[3].rm_so, pmatch[3].rm_eo-pmatch[3].rm_so);
-		day = buf.Mid(pmatch[2].rm_so, pmatch[2].rm_eo-pmatch[2].rm_so);
-		hour = buf.Mid(pmatch[5].rm_so, pmatch[5].rm_eo-pmatch[5].rm_so);
-		minute = buf.Mid(pmatch[6].rm_so, pmatch[6].rm_eo-pmatch[6].rm_so);
-		second = buf.Mid(pmatch[7].rm_so, pmatch[7].rm_eo-pmatch[7].rm_so);
-		zone = buf.Mid(pmatch[8].rm_so, pmatch[8].rm_eo-pmatch[8].rm_so);
-	}
-	regfree(&reg);
-
-	if(month.Find("Apr") != -1) month = "04";
-	else if(month.Find("May") != -1) month = "05";
-	else if(month.Find("Jun") != -1) month = "06";
-	else if(month.Find("Jul") != -1) month = "07";
-	else if(month.Find("Aug") != -1) month = "08";
-	else if(month.Find("Sep") != -1) month = "09";
-	else if(month.Find("Oct") != -1) month = "10";
-	else if(month.Find("Nov") != -1) month = "11";
-	else if(month.Find("Dec") != -1) month = "12";
-	else if(month.Find("Jan") != -1) month = "01";
-	else if(month.Find("Feb") != -1) month = "02";
-	else if(month.Find("Mar") != -1) month = "03";
-	else{
-		buf.Empty();
-		return buf;
-	}
-
-	CTime t(atoi(year), atoi(month), atoi(day), atoi(hour), atoi(minute), atoi(second));
-	if(!zone.IsEmpty()){
-		// adjust time zone
-		CString dif_plus_minus;
-		CString dif_hour;
-		CString dif_minute;
-		CString loc_plus_minus;
-		CString loc_hour;
-		CString loc_minute;
-		CString loc_zone;
-		// if not offset
-		if(!zone.SpanExcluding("0123456789+-").IsEmpty()){
-			zone = g_get_tzoffset_from_tzname(zone);
-		}
-		dif_plus_minus = zone[0];
-		dif_hour = zone.Mid(1, 2);
-		dif_minute = zone.Mid(3, 2);
-		// change to GMT
-		if(dif_plus_minus == "-"){
-			t += CTimeSpan(0, atoi(dif_hour), atoi(dif_minute), 0);
-		}else if(dif_plus_minus == "+"){
-			t -= CTimeSpan(0, atoi(dif_hour), atoi(dif_minute), 0);
-		}
-		// change local time
-		loc_zone = DEF_TIME_ZONE;
-		loc_plus_minus = loc_zone[0];
-		loc_hour = loc_zone.Mid(1, 2);
-		loc_minute = loc_zone.Mid(3, 2);
-		if(loc_plus_minus == "-"){
-			t -= CTimeSpan(0, atoi(loc_hour), atoi(loc_minute), 0);
-		}else if(loc_plus_minus == "+"){
-			t += CTimeSpan(0, atoi(loc_hour), atoi(loc_minute), 0);
-		}
-	}
-
-	return t.Format("%Y/%m/%d %H:%M:%S");
-}
-
 void CHeaderInfo::AnalyzeCT()
 {
 	regex_t reg; // for regex
@@ -668,7 +553,7 @@ void CHeaderInfo::InitMemVal()
 	m_subtype.Empty();
 	m_type.Empty();
 	m_protocol.Empty();
-	m_xattachment.Empty();
+	m_popfile_link.Empty();
 	m_decoded_header.RemoveAll();
 	m_undecoded_header.RemoveAll();
 	m_enc = SEVEN_BIT; // 7bit
@@ -700,3 +585,11 @@ void CHeaderInfo::RemoveLinearWhiteSpace(CStringArray *header)
 	}
 	regfree(&reg);
 }
+
+CString CHeaderInfo::GetHeaderFieldBody(CString field_name)
+{
+	CString buf = GetOneLine(field_name);
+	buf = buf.Mid(buf.Find(":")+1);
+	buf.TrimRight("\r\n");
+	return buf;
+}
