@@ -58,22 +58,18 @@ BEGIN_MESSAGE_MAP(CMainFrame, CFrameWnd)
 	ON_COMMAND(ID_GPG, OnGpg)
 	ON_UPDATE_COMMAND_UI(ID_GPG_DEC, OnUpdateGpgDec)
 	ON_UPDATE_COMMAND_UI(ID_GPG, OnUpdateGpg)
-	ON_UPDATE_COMMAND_UI(ID_GPG_MAIN_KEY_MANAGEMENT, OnUpdateGpg)
 	ON_COMMAND(ID_RETRIEVE, OnRetrieve)
+	ON_COMMAND(ID_RETRIEVE_NEXT, OnRetrieveNext)
 	ON_WM_DESTROY()
 	ON_COMMAND(ID_SETTING, OnSetting)
 	ON_COMMAND(ID_REPLY, OnReply)
 	ON_COMMAND(ID_DRAFT, OnDraft)
-	ON_COMMAND(ID_DRAFT_DEFAULT, OnDraft)
 	ON_COMMAND(ID_ADDRESS, OnAddress)
 	ON_UPDATE_COMMAND_UI(ID_TRANSFER, OnUpdateTransfer)
 	ON_COMMAND(ID_INFO, OnInfo)
 	ON_UPDATE_COMMAND_UI(ID_INFO, OnUpdateInfo)
-	ON_UPDATE_COMMAND_UI(ID_DISPLAY_HEADER, OnUpdateInfo)
-	ON_UPDATE_COMMAND_UI(ID_DISPLAY_RAW_MAIL, OnUpdateInfo)
 	ON_UPDATE_COMMAND_UI(ID_SETTING, OnUpdateSetting)
 	ON_NOTIFY(TBN_DROPDOWN, AFX_IDW_TOOLBAR, OnToolbarDropDown)
-	ON_COMMAND(ID_REPLY_DEFAULT, OnReply)
 	ON_WM_TIMER()
 	ON_COMMAND(ID_SETTING_GENERAL, OnSettingGeneral)
 	ON_COMMAND(ID_SETTING_ACCOUNT, OnSettingAccount)
@@ -85,9 +81,16 @@ BEGIN_MESSAGE_MAP(CMainFrame, CFrameWnd)
 	ON_COMMAND(ID_GPG_MAIN_KEY_MANAGEMENT, OnGpgKeyManagement)
 	ON_COMMAND(ID_SWITCH_VIEW, OnSwitchView)
 	ON_COMMAND(ID_SCROLL_MAIL, OnScrollMail)
+	ON_COMMAND(ID_SHOW_PLUGIN_LIST, OnShowPluginList)
 	ON_WM_CLOSE()
 	ON_WM_COPYDATA()
 	ON_WM_SYSCOMMAND()
+	ON_WM_ACTIVATE()
+	ON_UPDATE_COMMAND_UI(ID_GPG_MAIN_KEY_MANAGEMENT, OnUpdateGpg)
+	ON_COMMAND(ID_DRAFT_DEFAULT, OnDraft)
+	ON_UPDATE_COMMAND_UI(ID_DISPLAY_HEADER, OnUpdateInfo)
+	ON_UPDATE_COMMAND_UI(ID_DISPLAY_RAW_MAIL, OnUpdateInfo)
+	ON_COMMAND(ID_REPLY_DEFAULT, OnReply)
 	//}}AFX_MSG_MAP
 	ON_COMMAND(WM_PROGCREATE, OnProgCreate)
 END_MESSAGE_MAP()
@@ -306,11 +309,15 @@ BOOL CMainFrame::OnCreateClient(LPCREATESTRUCT lpcs, CCreateContext* pContext)
 	y = app->GetProfileInt("SplitWnd", "HeaderViewHeight", DEF_HEADER_HEIGHT);
 	m_split_header_text.SetRowInfo(0, y, 10);
 
-	// hide multipartview
+	// hide each view
 	this->HideMultiPartView(TRUE);
 	if(!app->GetProfileInt("Customize", "HeaderView", 1)){
 		this->HideHeaderView(TRUE);
 	}
+	if (app->GetProfileInt(_T("Customize"), _T("AccountViewHide"), 0))
+	{
+		HideAccountView(TRUE);
+	}
 
 	m_flag = TRUE;
 	return TRUE;
@@ -416,54 +423,49 @@ void CMainFrame::OnGpgDec()
 		CString content_disposition;
 
 		// rearrange for connonical mime in pgp/mime
-		int i=0;
-		while(i < new_header.GetSize()){
+		int i;
+		int max = new_header.GetSize();
+		for(i=0; i<max; i++){
 			if(0 == new_header.GetAt(i).Find("Content-Type"))
 				content_type = new_header.GetAt(i);
 			if(0 == new_header.GetAt(i).Find("Content-Transfer-Encoding"))
 				content_transfer_encoding = new_header.GetAt(i);
 			if(0 == new_header.GetAt(i).Find("Content-Disposition"))
 				content_disposition = new_header.GetAt(i);
-			i++;
 		}
 
-		int j=0;
-		while(j < old_header.GetSize()){
-			if(0 == old_header.GetAt(j).Find("Content-Type")){
+		max = old_header.GetSize();
+		for(i=0; i<max; i++){
+			if(0 == old_header.GetAt(i).Find("Content-Type")){
 				if(content_type.IsEmpty())
-					old_header.SetAt(j, "Content-Type: Text/Plain; charset=ISO-2022-JP\r\n");
+					old_header.SetAt(i, "Content-Type: text/plain; charset=ISO-2022-JP\r\n");
 				else
-					old_header.SetAt(j, content_type);
+					old_header.SetAt(i, content_type);
 			}
-			j++;
 		}
 
-		j=0;
-		while(j < old_header.GetSize()){
-			if(0 == old_header.GetAt(j).Find("Content-Transfer-Encoding")){
+		for(i=0; i<max; i++){
+			if(0 == old_header.GetAt(i).Find("Content-Transfer-Encoding")){
 				if(content_transfer_encoding.IsEmpty())
-					old_header.SetAt(j, "Content-Transfer-Encoding: 7bit\r\n");
+					old_header.SetAt(i, "Content-Transfer-Encoding: 7bit\r\n");
 				else
-					old_header.SetAt(j, content_transfer_encoding);
-			}		
-			j++;		
+					old_header.SetAt(i, content_transfer_encoding);
+			}
 		}
 
-		j=0;
-		while(j < old_header.GetSize()){
-			if(0 == old_header.GetAt(j).Find("Content-Disposition"))
+		for(i=0; i<max; i++){
+			if(0 == old_header.GetAt(i).Find("Content-Disposition"))
 				if(content_disposition.IsEmpty())
-					old_header.RemoveAt(j);
+					old_header.RemoveAt(i);
 				else
-					old_header.SetAt(j, content_disposition);
-			j++;
+					old_header.SetAt(i, content_disposition);
 		}
 
 		body = buf.Mid(buf.Find("\r\n\r\n")+4);
 	}else{
 		body = buf; // in case of none pgp/mime, may be encoded word is directly put into mail body
 	}
-	g_cstra2cstr(old_header, header, g_cstra_getsize(old_header));
+	g_cstringarray2cstring(old_header, header);
 	header.TrimRight();
 	header += "\r\n";
 	m_pTextV->Update2(header+"\r\n"+body);
@@ -491,6 +493,12 @@ void CMainFrame::OnRetrieve()
 	Retrieve.GoRetrieve(path, FIRST);
 }
 
+void CMainFrame::OnRetrieveNext()
+{
+	CRetrieve Retrieve;
+	Retrieve.GoRetrieve(m_pListV->m_path, CONTINUE);
+}
+
 void CMainFrame::OnDestroy()
 {
 	CPochyApp *app = (CPochyApp *)AfxGetApp();
@@ -517,7 +525,7 @@ void CMainFrame::OnDestroy()
 	// saving width of column in summaryview into ini file
 	for(int i = 0; i < 5; i++){
 		num.Format("%d", i);
-		app->WriteProfileInt("SummaryViewColumn", num.GetBuffer(0), m_pListV->GetListCtrl().GetColumnWidth(i));
+		app->WriteProfileInt("SummaryViewColumn", num, m_pListV->GetListCtrl().GetColumnWidth(i));
 	}
 
 	// saving order of column in summaryview into ini file
@@ -526,7 +534,7 @@ void CMainFrame::OnDestroy()
 	// saving width of column in multipartview into ini file
 	for(i = 0; i < 3; i++){
 		num.Format("%d", i);
-		app->WriteProfileInt("MultiPartViewColumn", num.GetBuffer(0), m_pMultiV->GetListCtrl().GetColumnWidth(i));
+		app->WriteProfileInt("MultiPartViewColumn", num, m_pMultiV->GetListCtrl().GetColumnWidth(i));
 	}
 
 	// saving size of each splited pane into ini file
@@ -590,6 +598,9 @@ void CMainFrame::OnReply()
 	}
 
 	CPochyApp *app = (CPochyApp *)AfxGetApp();
+	CStringArray array_to;
+	CStringArray array_cc;
+	CStringArray array_tmp;
 	CTemplate tmpl;
 	CString body_tmpl;
 	CMainAddressCheckDlg ad;
@@ -599,15 +610,27 @@ void CMainFrame::OnReply()
 	// initialyze
 	app->m_me.Initialize();
 
-	if(!m_pTextV->GetCurrentCc().IsEmpty()){
+	g_split_address(m_pTextV->GetCurrentTo(), array_tmp, FALSE, FALSE);
+
+	if(!m_pTextV->GetCurrentCc().IsEmpty() || array_tmp.GetSize() > 1){
 		// setting cc
-		ad.SetCc(m_pTextV->GetCurrentCc());
-					
+		if(!m_pTextV->GetCurrentCc().IsEmpty()){
+			g_split_address(m_pTextV->GetCurrentCc(), array_cc, FALSE, FALSE);
+		}
+		if(array_tmp.GetSize() > 1){
+			array_cc.Append(array_tmp);
+		}
+		if(array_cc.GetSize() > 0){
+			ad.SetCc(array_cc);
+		}
+
 		// setting to, if reply-to exist, use reply-to address as to address
 		if(m_pTextV->GetCurrentReplyTo().IsEmpty()){
-			ad.SetTo(m_pTextV->GetCurrentFrom());
+			g_split_address(m_pTextV->GetCurrentFrom(), array_to, FALSE, FALSE);
+			ad.SetTo(array_to);
 		}else{
-			ad.SetTo(m_pTextV->GetCurrentReplyTo());
+			g_split_address(m_pTextV->GetCurrentReplyTo(), array_to, FALSE, FALSE);
+			ad.SetTo(array_to);
 		}
 
 		if(ad.DoModal() == IDOK){
@@ -770,6 +793,8 @@ void CMainFrame::OnInfo()
 
 void CMainFrame::OnSwitchView()
 {
+	bool bAccountViewActive = m_split_account_folder.GetRowCount() == 2;
+
 	CWnd* wnd = GetFocus();
 	if(wnd == m_pTreeV)
 		m_pListV->SetFocus();
@@ -777,9 +802,9 @@ void CMainFrame::OnSwitchView()
 		m_pTextV->SetFocus();
 	else if(wnd == m_pTextV && !m_multipart_hide)
 		m_pMultiV->SetFocus();
-	else if(wnd == m_pTextV && m_multipart_hide)
+	else if(wnd == m_pTextV && m_multipart_hide && bAccountViewActive)
 		m_pAcntV->SetFocus();
-	else if(wnd == m_pMultiV)
+	else if(wnd == m_pMultiV && bAccountViewActive)
 		m_pAcntV->SetFocus();
 	else
 		m_pTreeV->SetFocus();
@@ -888,7 +913,7 @@ BOOL CMainFrame::CreateToolbar()
 	return TRUE;
 }
 
-BOOL CMainFrame::OnToolbarDropDown(NMHDR* pNMHDR, LRESULT *plr)
+void CMainFrame::OnToolbarDropDown(NMHDR* pNMHDR, LRESULT *plr)
 {
 	CPochyApp* app = (CPochyApp*)AfxGetApp();
 	CFileFind ff;
@@ -918,7 +943,7 @@ BOOL CMainFrame::OnToolbarDropDown(NMHDR* pNMHDR, LRESULT *plr)
 		id = IDR_MAINFRAME_POPUP_SETTING;
 		break;
 	default:
-		return TRUE;
+		return;
 	}
 	
 	// load and display popup menu
@@ -991,7 +1016,7 @@ BOOL CMainFrame::OnToolbarDropDown(NMHDR* pNMHDR, LRESULT *plr)
 	
 	pPopup->TrackPopupMenu( TPM_LEFTALIGN | TPM_LEFTBUTTON | TPM_VERTICAL, rc.left, rc.bottom, this, &rc);
 
-	return TRUE;
+	return;
 }
 
 void CMainFrame::OnGpg()
@@ -1047,8 +1072,8 @@ void CMainFrame::UpdateButton1(BOOL b, CString account)
 	m_pAcntV->m_data[index].button_fetchmail = b;
 	m_pAcntV->m_data[index].button_setting = b;
 	m_pAcntV->m_data[index].button_retrieve = b;
-	this->Invalidate(TRUE);
-	this->RedrawWindow();
+	Invalidate(TRUE);
+	UpdateWindow();
 }
 
 void CMainFrame::UpdateButton2(BOOL b)
@@ -1112,14 +1137,22 @@ void CMainFrame::OnSettingAccount()
 void CMainFrame::OnDisplayHeader() 
 {
 	CPochyApp *app = (CPochyApp *)AfxGetApp();
-	CString file_name = g_ma(m_pTextV->GetCurrentMsgID())+"_header.txt";
+	CString msg_id = g_ma(m_pTextV->GetCurrentMsgID());
+	msg_id.Remove('.');
+	msg_id.Remove('/');
+	msg_id.Remove(':');
+	msg_id.Remove('*');
+	msg_id.Remove('?');
+	msg_id.Remove('\"');
+	msg_id.Remove('|');
+	CString file_name = msg_id+"_header.txt";
 
 	if(!g_is_there(app->m_app_path+"\\temp")) // if attached folder does not exist, create.
 		_mkdir(app->m_app_path+"\\temp");
 	CString file_path = app->m_app_path+"\\temp\\"+file_name;
 
 	FILE* file = fopen(file_path, "wb");
-	fwrite(m_pTextV->GetCurrentRawHeader().GetBuffer(0), sizeof(char), m_pTextV->GetCurrentRawHeader().GetLength(), file);
+	fwrite(m_pTextV->GetCurrentRawHeader(), sizeof(char), m_pTextV->GetCurrentRawHeader().GetLength(), file);
 	fclose(file);
 
 	CString editor_path = app->GetProfileString("Editor", "Path", "notepad");
@@ -1146,7 +1179,7 @@ void CMainFrame::OnSettingFilter()
 	CString file = app->m_app_path+"\\"+m_pAcntV->GetCurrentAccountName()+"\\"+"filter";
 	// if filter file does not exist, create.
 	if(!g_is_there(file)){
-		g_cstring2file(FILTER_INSTRUCTION, file);
+		g_string2file(FILTER_INSTRUCTION, file);
 	}
 	CString path = app->GetProfileString("Editor", "Path", "notepad");
 	if(path.IsEmpty())
@@ -1171,6 +1204,7 @@ void CMainFrame::OnSettingNewAccount()
 
 	this->m_pAcntV->CreateNewAccount(name);
 	this->m_pTreeV->ConstructTree(name);
+	m_pTreeV->SelectInbox(name);
 
 	// if multipartview is on display, hide
 	this->m_pListV->Clear();
@@ -1251,6 +1285,11 @@ void CMainFrame::OnClose()
 {
 	CPochyApp *app = (CPochyApp *)AfxGetApp();
 
+	if (app->m_pluginManager.OnClose() == PR_CLOSE_CANCEL)
+	{
+		return;
+	}
+
 	LONG lStyle = ::GetWindowLong(m_wndToolBar.GetSafeHwnd(), GWL_STYLE);
 	if ((lStyle & WS_VISIBLE) == WS_VISIBLE){
 		app->WriteProfileInt("ToolBar", "IsVisible", SW_SHOW);
@@ -1360,24 +1399,38 @@ LRESULT CMainFrame::OnNotifyIcon(WPARAM wParam, LPARAM lParam)
 				POINT point;
 				if (::GetCursorPos(&point) != 0)
 				{
-					CMenu* pSystemMenu = GetSystemMenu(FALSE);
-					if (pSystemMenu != NULL)
+					CMenu menu;
+					if (menu.CreatePopupMenu())
 					{
-//						SetFocus();
-						pSystemMenu->DeleteMenu(SC_MOVE, MF_BYCOMMAND);
-						pSystemMenu->DeleteMenu(SC_SIZE, MF_BYCOMMAND);
-						pSystemMenu->DeleteMenu(SC_MINIMIZE, MF_BYCOMMAND);
-						pSystemMenu->DeleteMenu(SC_MAXIMIZE, MF_BYCOMMAND);
-						if (!IsIconic())
+						CMenu* pSystemMenu = GetSystemMenu(FALSE);
+						if (pSystemMenu != NULL)
 						{
-							pSystemMenu->DeleteMenu(SC_RESTORE, MF_BYCOMMAND);
-							pSystemMenu->DeleteMenu(0, MF_BYPOSITION);
+							CString menuString;
+							if (IsIconic())
+							{
+								pSystemMenu->GetMenuString(SC_RESTORE, menuString, MF_BYCOMMAND);
+								menu.AppendMenu(MF_STRING, SC_RESTORE, menuString);
+								menu.AppendMenu(MF_SEPARATOR);
+							}
+							pSystemMenu->GetMenuString(SC_CLOSE, menuString, MF_BYCOMMAND);
+							menu.AppendMenu(MF_STRING, SC_CLOSE, menuString);
+							CPochyApp* pPochyApp = (CPochyApp*)::AfxGetApp();
+							if (pPochyApp != NULL)
+							{
+								pPochyApp->m_pluginManager.OnInitMenu(menu.GetSafeHmenu(), POCHY_MENU_TASKTRAY);
+							}
+							UINT uItem = menu.TrackPopupMenu(
+								TPM_RIGHTALIGN | TPM_LEFTBUTTON | TPM_RIGHTBUTTON | TPM_RETURNCMD,
+								point.x, point.y, this);
+							if (uItem == SC_CLOSE || uItem == SC_RESTORE)
+							{
+								PostMessage(WM_SYSCOMMAND, uItem, NULL);
+							}
+							else
+							{
+								CallPluginCallback(GetSafeHwnd(), uItem);
+							}
 						}
-						UINT uItem = pSystemMenu->TrackPopupMenu(
-							TPM_RIGHTALIGN | TPM_LEFTBUTTON | TPM_RIGHTBUTTON | TPM_RETURNCMD,
-							point.x, point.y, this, NULL);
-						PostMessage(WM_SYSCOMMAND, uItem, NULL);
-						GetSystemMenu(TRUE);
 					}
 				}
 			}
@@ -1407,7 +1460,7 @@ LRESULT CMainFrame::WindowProc(UINT message, WPARAM wParam, LPARAM lParam)
 	{
 		m_notifyIcon.Add();
 	}
-	
+
 	return CFrameWnd::WindowProc(message, wParam, lParam);
 }
 
@@ -1430,6 +1483,8 @@ void CMainFrame::OnSysCommand(UINT nID, LPARAM lParam)
 	default:
 		break;
 	}
+
+	CallPluginCallback(this->GetSafeHwnd(), nID);
 }
 
 void CMainFrame::StartTaskTrayAnimation()
@@ -1460,15 +1515,30 @@ void CMainFrame::HideHeaderView(BOOL b)
 	}
 }
 
+void CMainFrame::HideAccountView(BOOL bHide)
+{
+	if (bHide)
+	{
+		m_split_account_folder.HideRow(0);
+	}
+	else
+	{
+		m_split_account_folder.ShowRow();
+	}
+}
+
 BOOL CMainFrame::OnCmdMsg(UINT nID, int nCode, void* pExtra, AFX_CMDHANDLERINFO* pHandlerInfo) 
 {
 	CPochyApp *app = (CPochyApp *)AfxGetApp();
+	CStringArray array_to;
+	CStringArray array_cc;
+	CStringArray array_tmp;
 	CString menu_item;
 	CTemplate tmpl;
 	CString body_tmpl;
 	CMainAddressCheckDlg ad;
 
-	// pHandlerInfo == NUUL means this message id is not assigned to any hendler
+	// pHandlerInfo == NUUL means this message id is not assigned to any handler
 	if(pHandlerInfo == NULL && ID_DYNAMIC_DROP_DOWN_MENU_START <= nID && nID <= ID_DYNAMIC_DROP_DOWN_MENU_END){
 		if(nCode == CN_COMMAND){
 			menu_item = this->m_template_array.GetAt(nID-ID_DYNAMIC_DROP_DOWN_MENU_START);
@@ -1527,15 +1597,27 @@ BOOL CMainFrame::OnCmdMsg(UINT nID, int nCode, void* pExtra, AFX_CMDHANDLERINFO*
 				// initialyze
 				app->m_me.Initialize();
 
-				if(!m_pTextV->GetCurrentCc().IsEmpty()){
+				g_split_address(m_pTextV->GetCurrentTo(), array_tmp, FALSE, FALSE);
+
+				if(!m_pTextV->GetCurrentCc().IsEmpty() || array_tmp.GetSize() > 1){
 					// setting cc
-					ad.SetCc(m_pTextV->GetCurrentCc());
-					
+					if(!m_pTextV->GetCurrentCc().IsEmpty()){
+						g_split_address(m_pTextV->GetCurrentCc(), array_cc, FALSE, FALSE);
+					}
+					if(array_tmp.GetSize() > 1){
+						array_cc.Append(array_tmp);
+					}
+					if(array_cc.GetSize() > 0){
+						ad.SetCc(array_cc);
+					}
+
 					// setting to, if reply-to exist, use reply-to address as to address
 					if(m_pTextV->GetCurrentReplyTo().IsEmpty()){
-						ad.SetTo(m_pTextV->GetCurrentFrom());
+						g_split_address(m_pTextV->GetCurrentFrom(), array_to, FALSE, FALSE);
+						ad.SetTo(array_to);
 					}else{
-						ad.SetTo(m_pTextV->GetCurrentReplyTo());
+						g_split_address(m_pTextV->GetCurrentReplyTo(), array_to, FALSE, FALSE);
+						ad.SetTo(array_to);
 					}
 
 					if(ad.DoModal() == IDOK){
@@ -1671,6 +1753,17 @@ BOOL CMainFrame::OnCmdMsg(UINT nID, int nCode, void* pExtra, AFX_CMDHANDLERINFO*
 	return CFrameWnd::OnCmdMsg(nID, nCode, pExtra, pHandlerInfo);
 }
 
+void CMainFrame::OnActivate(UINT nState, CWnd* pWndOther, BOOL bMinimized) 
+{
+	CFrameWnd::OnActivate(nState, pWndOther, bMinimized);
+
+	if (!bMinimized)
+	{
+		CPochyApp* pPochyApp = (CPochyApp*)::AfxGetApp();
+		pPochyApp->m_pluginManager.OnActivate(nState);
+	}
+}
+
 bool CMainFrame::CreateFolderList(const std::string& path, std::vector<std::string>& folderList)
 {
 	bool bResult = false;
@@ -1768,7 +1861,7 @@ bool CMainFrame::SelectNextUnreadFolder()
 
 			// ǂtH_[I
 			// ĂJ
-			pFolderView->SelectFolder(unreadFolderPath);
+			pFolderView->SelectFolder(unreadFolderPath.c_str());
 
 			bResult = true;
 		}
@@ -1821,22 +1914,19 @@ void CMainFrame::OnScrollMail()
 	m_pTextV->GetRichEditCtrl().LineScroll(sc);
 }
 
+void CMainFrame::OnShowPluginList()
+{
+	CPluginListDialog dialog;
+	dialog.DoModal();
+}
+
+void CMainFrame::AddMenuCallback(const int nID, POCHY_MENU_CALLBACK callback)
+{
+	m_menuCallbackMap.insert(MENU_CALLBACK_MAP::value_type(nID, callback));
+}
+
 BOOL CMainFrame::PreTranslateMessage(MSG* pMsg) 
 {
-	if (pMsg->message == WM_CHAR)
-	{
-		CPochyApp* app = (CPochyApp*)AfxGetApp();
-		if(app->m_retrieving)
-		{
-			//ESCL[ȊOȂ
-			if (LOWORD(pMsg->wParam) == VK_ESCAPE)
-			{
-				app->m_retrieving = 0;
-			}
-			return TRUE;
-		}
-	}
-
 	if (m_acceleratorTable.TranslateAccelerator(m_hWnd, pMsg))
 	{
 		return TRUE;
@@ -1890,9 +1980,25 @@ BOOL CMainFrame::OnCommand(WPARAM wParam, LPARAM lParam)
 		break;
 	}
 
+	CallPluginCallback(this->GetSafeHwnd(), LOWORD(wParam));
+
 	return CFrameWnd::OnCommand(wParam, lParam);
 }
 
+// vOCR[obNo^Ă郁bZ[WȂR[obNĂяo
+void CMainFrame::CallPluginCallback(HWND hWnd, UINT nID)
+{
+	if (hWnd != NULL && ::IsWindow(hWnd))
+	{
+		MENU_CALLBACK_MAP::const_iterator it;
+		it = m_menuCallbackMap.find(nID);
+		if (it != m_menuCallbackMap.end())
+		{
+			it->second(hWnd, nID);
+		}
+	}
+}
+
 void CMainFrame::LoadAccelerator()
 {
 	CPochyApp *app = (CPochyApp*)AfxGetApp();
@@ -1912,7 +2018,7 @@ void CMainFrame::SetAcceleratorTargetWindow()
 	m_acceleratorTable.AddTargetWindow(m_pTextV->GetSafeHwnd());
 	m_acceleratorTable.AddTargetWindow(m_pHeadV->GetSafeHwnd());
 	m_acceleratorTable.AddTargetWindow(m_pMultiV->GetSafeHwnd());
-//	m_acceleratorTable.AddTargetWindow(m_pListV->GetParent()->GetSafeHwnd());
+	m_acceleratorTable.AddTargetWindow(m_pListV->GetParent()->GetSafeHwnd());
 }
 
 void CMainFrame::LoadDefaultAccelerator()
@@ -1922,13 +2028,14 @@ void CMainFrame::LoadDefaultAccelerator()
 	////////////////// MainFrame ////////////////////////////////////////////////////////////////////////////////////////
 	// mail
 	m_acceleratorTable.AddAccelerator(_T("Receive"),			ID_FETCH_MAIL,				_T("i"),		_T("M(&V)"));
-	m_acceleratorTable.AddAccelerator(_T("ReplyMail"),			ID_REPLY,					_T("a"),		_T("ԐM(&R)"));
-//	m_acceleratorTable.AddAccelerator(_T("ReplyQuotation"),		ID_REPLY_QUOTATION,			_T("Shift+a"),	_T("pԐM));
-//	m_acceleratorTable.AddAccelerator(_T("ReplyNoQuotation"),	ID_REPLY_NO_QUOTATION,		_T("a"),		_T("pȂԐM"));
-	m_acceleratorTable.AddAccelerator(_T("Forward"),			ID_TRANSFER,				_T("f"),		_T("](&T)"));
-//	m_acceleratorTable.AddAccelerator(_T("ForwardMail"),		ID_TRANSFER_QUOTATION,		_T("f"),		_T("](&T)"));
-	m_acceleratorTable.AddAccelerator(_T("NewMail"),			ID_DRAFT,					_T("w"),		_T("M(&N)"));
-	m_acceleratorTable.AddAccelerator(_T("Find"),				ID_RETRIEVE,				_T("Ctrl+F"),	_T("(&F)"));
+	m_acceleratorTable.AddAccelerator(_T("ReplyMail"),			ID_REPLY,					_T("a"),		_T("ԐM(&R)..."));
+//	m_acceleratorTable.AddAccelerator(_T("ReplyQuotation"),		ID_REPLY_QUOTATION,			_T("Shift+a"),	_T("pԐM...));
+//	m_acceleratorTable.AddAccelerator(_T("ReplyNoQuotation"),	ID_REPLY_NO_QUOTATION,		_T("a"),		_T("pȂԐM..."));
+	m_acceleratorTable.AddAccelerator(_T("Forward"),			ID_TRANSFER,				_T("f"),		_T("](&T)..."));
+//	m_acceleratorTable.AddAccelerator(_T("ForwardMail"),		ID_TRANSFER_QUOTATION,		_T("f"),		_T("](&T)..."));
+	m_acceleratorTable.AddAccelerator(_T("NewMail"),			ID_DRAFT,					_T("w"),		_T("M(&N)..."));
+	m_acceleratorTable.AddAccelerator(_T("Find"),				ID_RETRIEVE,				_T("Ctrl+F"),	_T("(&F)..."));
+	m_acceleratorTable.AddAccelerator(_T("FindNext"),			ID_RETRIEVE_NEXT,			_T("Tab"),		_T(""));
 
 	// GPG
 	m_acceleratorTable.AddAccelerator(_T("GPGKeyManagement"),	ID_GPG_MAIN_KEY_MANAGEMENT,	_T("Ctrl+G"),	_T("̊Ǘ(&G)"));
@@ -1952,6 +2059,9 @@ void CMainFrame::LoadDefaultAccelerator()
 	m_acceleratorTable.AddAccelerator(_T("SwitchView"),			ID_SWITCH_VIEW,				_T("Ctrl+O"),	_T("r[̃tH[JX؂ւ"));
 	m_acceleratorTable.AddAccelerator(_T("ScrollMail"),			ID_SCROLL_MAIL,				_T(""),			_T("[XN["));
 
+	// plugin
+	m_acceleratorTable.AddAccelerator(_T("PluginInfo"),			ID_PLUGIN_INFO,				_T(""),			_T("vOC\(&I)..."));
+
 	////////////////// Summary View ////////////////////////////////////////////////////////////////////////////////////////
 	m_acceleratorTable.AddAccelerator(_T("CheckDeleteMark"),	ID_CHECK_DELETE_MARK,		_T("d"),		_T("폜}[N"));
 	m_acceleratorTable.AddAccelerator(_T("UncheckDeleteMark"),	ID_UNCHECK_DELETE_MARK,		_T("u"),		_T("폜}[N"));
