@@ -15,6 +15,8 @@
 #include "HeaderView.h"
 #include "NotifyIcon.h"
 #include "AcceleratorTable.h"
+#include "PochyPlugin.h"
+#include "PluginListDialog.h"
 
 #if _MSC_VER > 1000
 #pragma once
@@ -48,10 +50,13 @@ public:
 
 // Cve[V
 public:
+	void CallPluginCallback(HWND hWnd, UINT nID);
+	void AddMenuCallback(const int nID, POCHY_MENU_CALLBACK callback);
 	bool SelectNextUnreadFolder();
 	void SetAcceleratorTargetWindow();
 	void LoadDefaultAccelerator();
 	void LoadAccelerator();
+	void HideAccountView(BOOL bHide);
 	void HideHeaderView(BOOL b);
 	void StopTaskTrayAnimation();
 	void StartTaskTrayAnimation();
@@ -87,6 +92,8 @@ public:
 	virtual void Dump(CDumpContext& dc) const;
 #endif
 private:
+	typedef std::map<int, POCHY_MENU_CALLBACK> MENU_CALLBACK_MAP;
+	MENU_CALLBACK_MAP m_menuCallbackMap;
 	const std::string FindUnreadFolderPath(const std::vector<std::string>& folderList, const std::string& startFolderPath);
 	bool CreateFolderList(const std::string& path, std::vector<std::string>& folderList);
 	CAcceleratorTable m_acceleratorTable;
@@ -116,6 +123,7 @@ protected:
 	afx_msg void OnUpdateGpgDec(CCmdUI* pCmdUI);
 	afx_msg void OnUpdateGpg(CCmdUI* pCmdUI);
 	afx_msg void OnRetrieve();
+	afx_msg void OnRetrieveNext();
 	afx_msg void OnDestroy();
 	afx_msg void OnSetting();
 	afx_msg void OnReply();
@@ -125,7 +133,7 @@ protected:
 	afx_msg void OnInfo();
 	afx_msg void OnUpdateInfo(CCmdUI* pCmdUI);
 	afx_msg void OnUpdateSetting(CCmdUI* pCmdUI);
-	afx_msg BOOL OnToolbarDropDown(NMHDR *pNMHDR, LRESULT* plRes);
+	afx_msg void OnToolbarDropDown(NMHDR *pNMHDR, LRESULT* plRes);
 	afx_msg void OnTimer(UINT nIDEvent);
 	afx_msg void OnSettingGeneral();
 	afx_msg void OnSettingAccount();
@@ -137,9 +145,11 @@ protected:
 	afx_msg void OnGpgKeyManagement();
 	afx_msg void OnSwitchView();
 	afx_msg void OnScrollMail();
+	afx_msg void OnShowPluginList();
 	afx_msg void OnClose();
 	afx_msg BOOL OnCopyData(CWnd* pWnd, COPYDATASTRUCT* pCopyDataStruct);
 	afx_msg void OnSysCommand(UINT nID, LPARAM lParam);
+	afx_msg void OnActivate(UINT nState, CWnd* pWndOther, BOOL bMinimized);
 	//}}AFX_MSG
 	afx_msg void OnProgCreate();
 	DECLARE_MESSAGE_MAP()
