@@ -83,6 +83,7 @@
 #define IDD_SETTING_GENERAL_SKINSELECT  208
 #define IDD_MAIN_ADDRESS_CHECK          209
 #define IDR_MAINFRAME_POPUP_DRAFT       210
+#define IDD_PLUGIN_LIST                 211
 #define IDC_EDIT1                       1000
 #define IDC_EDIT2                       1001
 #define IDC_PROGRESS1                   1002
@@ -214,7 +215,9 @@
 #define IDC_ABOUTBOX_EDIT               1097
 #define IDC_SETTING_GENERAL_SHOW_UNREAD_COUNT 1097
 #define IDC_SETTING_GENERAL_SKIN_PATH   1098
+#define IDC_LIST_PLUGIN                 1098
 #define IDC_SETTING_GENERAL_SKIN_REF    1099
+#define IDC_EDIT_COMMENT                1099
 #define ID_DRAFT                        32771
 #define ID_FETCH_MAIL                   32773
 #define ID_SEND_MAIL                    32774
@@ -297,6 +300,9 @@
 #define ID_PAGE_DOWN                    32919
 #define ID_SCROLL_AND_NEXT_UNREAD       32920
 #define ID_DRAFT_DEFAULT                32921
+#define ID_RETRIEVE_NEXT                32922
+#define ID_PLUGIN_INFO                  32923
+#define ID_SHOW_PLUGIN_LIST             32924
 #define ID_DYNAMIC_DROP_DOWN_MENU_START 40000
 #define ID_DYNAMIC_DROP_DOWN_MENU_END   41000
 #define ID_INDICATOR_TEXT               59143
@@ -308,9 +314,9 @@
 #ifdef APSTUDIO_INVOKED
 #ifndef APSTUDIO_READONLY_SYMBOLS
 #define _APS_3D_CONTROLS                     1
-#define _APS_NEXT_RESOURCE_VALUE        211
-#define _APS_NEXT_COMMAND_VALUE         32922
-#define _APS_NEXT_CONTROL_VALUE         1098
+#define _APS_NEXT_RESOURCE_VALUE        212
+#define _APS_NEXT_COMMAND_VALUE         32925
+#define _APS_NEXT_CONTROL_VALUE         1100
 #define _APS_NEXT_SYMED_VALUE           101
 #endif
 #endif
