@@ -100,7 +100,7 @@ void CRetrieve::GoRetrieve(CString path, int Flag)
 
     // Ώۃt@C݂Ă邩ǂ
     // ݂ĂȂꍇ́Ã[v
-    hFile = FindFirstFile(tmp.GetBuffer(0), &wfd);
+    hFile = FindFirstFile(tmp, &wfd);
     if(hFile == INVALID_HANDLE_VALUE){
       cnt--;
       continue;
@@ -111,7 +111,7 @@ void CRetrieve::GoRetrieve(CString path, int Flag)
 
     // Ώۃt@Cւ̃nh쐬
     CStdioFile ReadFile;
-    ReadFile.Open(tmp.GetBuffer(0), CFile::modeRead | CFile::typeBinary | CFile::shareDenyNone);
+    ReadFile.Open(tmp, CFile::modeRead | CFile::typeBinary | CFile::shareDenyNone);
 
     // [̓eCStringɓǂݍ
     LPSTR pMail = mail.GetBuffer(ReadFile.GetLength());
@@ -152,9 +152,17 @@ void CRetrieve::GoRetrieve(CString path, int Flag)
 
     MSG msg;
     if (::PeekMessage(&msg, NULL, 0, 0, PM_REMOVE)){
-      if(msg.message != WM_LBUTTONDOWN){
-        ::TranslateMessage(&msg);
-        ::DispatchMessage(&msg);
+		if (msg.message == WM_KEYDOWN)
+		{
+			//ESCL[ȊOȂ
+			if (LOWORD(msg.wParam) == VK_ESCAPE)
+			{
+				app->m_retrieving = 0;
+			}
+		}
+		else if(msg.message == WM_PAINT){
+			::TranslateMessage(&msg);
+			::DispatchMessage(&msg);
       }
     }
     if(!app->m_retrieving){
