@@ -16,14 +16,18 @@ class CSock
 {
 // Agr[g
 public:
-	SOCKET m_sock;
-	int Connect6(char *server_name, char *port);
+	int Connect6(LPCTSTR server_name, LPCTSTR port);
 	void DisConnect();
-	int SockRead(CString& out);
+	int ReadLine(CString &out);
+	int SockWrite(LPCTSTR buf, int len);
+	int SockRead(char *buf, int len);
 #ifndef _IPV6_
-	int GetIP(LPCTSTR addr, LPSTR ip);
+	int GetIP(LPCTSTR addr, LPCTSTR ip);
 #endif
 
+private:
+	SOCKET m_sock;
+
 // Iy[V
 public:
 	CSock();
