@@ -33,10 +33,9 @@ public:
 	CString m_path; // path of currently selected mail
 	CListStackList m_array_list; // array list for ListStack
 
-
 private:
 	int m_unread;
-	int SetStack(CString path);
+	int SetStack(LPCTSTR path);
 
 	CImageList m_IconImage;
 	CFont m_cReadFont;
@@ -61,18 +60,19 @@ public:
 	void CSummaryView::GetSelectedMail(CUIntArray &index_array);
 	void Clear();
 	void MoveMail(CUIntArray &index_array, CString to, int what_kind_box);
-	void ClearAllMail(CString path);
+	void ClearAllMail(LPCTSTR path);
 	void ReBuildSummary(CString path, int mode);
 	void SetColumnOrderStatus(int status);
 	void QuickSort(int start, int end, int item_num, int order);
 	void QuickSortSwapStack(int i, int j);
 	int QuickSortPartition(int start, int end, int item_num, int order);
-	BOOL SaveMail(CString path, CStringArray &mail, int mail_status, int what_kind_box);
-	BOOL SaveMail(CString path, CString mail, int mail_staus, int what_kind_box);
+	BOOL SaveMail(LPCTSTR path, CStringArray &mail, int mail_status, int what_kind_box, CString &ret_path);
+	BOOL SaveMail(LPCTSTR path, CString mail, int mail_staus, int what_kind_box);
+	BOOL MakeShortCut(LPCTSTR org_file_path, LPCTSTR dst_folder_path, int mail_status, int what_kind_box);
 	void UpdateColumn(int flag);
 	void AddList(SLISTSTACK *addlist);
-	void SetItem(CString path);
-	void SetStatus(int nItem, CString status);
+	void SetItem(LPCTSTR path);
+	void SetStatus(int nItem, LPCTSTR status);
 	BOOL ClearStatus(int nItem);
 	BOOL UnmarkStatus(int nItem);
 	BOOL MarkDStatus(int nItem);
@@ -82,6 +82,8 @@ public:
 	void WriteList(); // write out m_array_list into list file
 
 public:
+	void SortWithRequiredCheck(int nColumn = -1, int nOrder = -1);
+	void SetNoSortHeader(BOOL b);
 	void SelectNextUnreadMail();
 	int GetUnreadCount(const CString& strPath);
 	void ReadIniColumnOrder();
@@ -99,6 +101,10 @@ public:
 	void SetSelectBkColor(COLORREF colColor);
 
 private:
+	int MakeCommaNumber(LPCTSTR lpszSrc, LPTSTR lpNumberStr, int cchNumber);
+	void Sort(int nColumn = -1, int nOrder = -1);
+	bool IsSortRequired(const CString& strPath = _T(""));
+	void SetSortRequired(const CString& strPath = _T(""), bool bSortRequired = false);
 	void SelectItem(const int& nSelect);
 	void RedrawUnreadCount();
 	int CalcUnreadCount(const CString& strPath);
