@@ -5,6 +5,7 @@
 #include "stdafx.h"
 #include "pochy.h"
 #include "Template.h"
+#include "TimeEx.h"
 
 #ifdef _DEBUG
 #undef THIS_FILE
@@ -51,12 +52,27 @@ void CTemplate::SetBody(CString body)
 
 CString CTemplate::GetString(CMimeDecode *md, CString tmpl)
 {
+	CPochyApp *app = (CPochyApp *)AfxGetApp();
+	CTimeEx time;
 	CString buf;
 	CString body;
+	CString tmp;
+	int p;
 
 	for(int i=0; i<tmpl.GetLength(); i++){
 		if(tmpl[i] == '%' && (i+1) < tmpl.GetLength()){
 			switch(tmpl[i+1]){
+			case '[':
+				i++;
+				p = i;
+				for(; i<tmpl.GetLength(); i++){
+					if(tmpl[i] == ']'){
+						tmp = tmpl.Mid(p+1, i-p-1);
+						buf += md->m_hi.GetHeaderFieldBody(tmp);
+						break;
+					}
+				}
+				continue;
 			case 'a':
 				buf += m_address;
 				i++;
@@ -66,7 +82,9 @@ CString CTemplate::GetString(CMimeDecode *md, CString tmpl)
 					if(md->m_hi.GetDate().IsEmpty()){
 						buf += "none";
 					}else{
-						buf += md->m_hi.GetDate();
+						time.SetMailFormatDate(md->m_hi.GetDate());
+						time.SetNewOffset(app->m_time_zone_offset);
+						buf += time.GetFormatDate(DEF_TIME_FORMAT);
 					}
 				}
 				i++;
@@ -145,6 +163,10 @@ CString CTemplate::GetString(CMimeDecode *md, CString tmpl)
 				buf += m_signature;
 				i++;
 				continue;
+			case 'p':
+				buf += md->m_hi.GetPopfileLink();
+				i++;
+				continue;
 			case '%':
 				buf += "%";
 				i++;
