@@ -15,12 +15,13 @@
 #include "sendmail.h"
 #include "PassPhraseDlg.h"
 #include "HeaderInfo.h"
-#include <Shlwapi.h> // StrStrI vWFNg̐ݒ̃N"Shlwapi.lib"ǉ
+//#include <Shlwapi.h> // StrStrI vWFNg̐ݒ̃N"Shlwapi.lib"ǉ
 #include "quoted-printable.h"
 #include "base64.h"
 #include "lib.h"
 #include "direct.h"			// _mkdir
 #include "Gpg.h"
+#include "_regex.h"
 
 #include "Template.h"
 
@@ -279,7 +280,7 @@ CString CTextView::GetCurrentText()
 
 BOOL CTextView::IsPgpMime()
 {
-	return g_cstr_compare(m_md.m_hi.GetProtocol(), "application/pgp-encrypted");
+	return g_string_compare_no_case(m_md.m_hi.GetProtocol(), "application/pgp-encrypted");
 }
 
 BOOL CTextView::OnLink(NMHDR* in_pNotifyHeader, LRESULT* out_pResult)
@@ -335,6 +336,45 @@ BOOL CTextView::OnLink(NMHDR* in_pNotifyHeader, LRESULT* out_pResult)
 				reply_to.ReleaseBuffer();
 				app->m_me.SetReplyTo(reply_to);
 
+				// getting signature.
+				CString signature;
+				g_file2cstring(app->m_app_path+"\\"+current_account+"\\signature", signature);
+				// set main text.
+				app->m_me.AddText(signature);
+				// draftframe
+				app->CreateDraftFrame(mf->m_pAcntV->GetCurrentAccountName());
+			}else if(link.Find("@") != -1){
+
+				// initialization.
+				app->m_me.Initialize();
+				// setting To
+				app->m_me.SetTo(link);
+
+				// setting From
+				CString path = app->m_app_path+"\\"+current_account+"\\account.ini";
+				CString address;
+				GetPrivateProfileString("mailbox", "address", "", address.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+				address.ReleaseBuffer();
+				app->m_me.SetFrom(address);
+
+				// setting "cc"
+				CString cc;
+				GetPrivateProfileString("def_address", "cc", "", cc.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+				cc.ReleaseBuffer();
+				app->m_me.SetCc(cc);
+
+				// setting "bcc"
+				CString bcc;
+				GetPrivateProfileString("def_address", "bcc", "", bcc.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+				bcc.ReleaseBuffer();
+				app->m_me.SetBcc(bcc);
+
+				// setting "reply-to"
+				CString reply_to;
+				GetPrivateProfileString("def_address", "reply_to", "", reply_to.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+				reply_to.ReleaseBuffer();
+				app->m_me.SetReplyTo(reply_to);
+
 				// getting signature.
 				CString signature;
 				g_file2cstring(app->m_app_path+"\\"+current_account+"\\signature", signature);
@@ -398,6 +438,45 @@ BOOL CTextView::OnLink(NMHDR* in_pNotifyHeader, LRESULT* out_pResult)
 				reply_to.ReleaseBuffer();
 				app->m_me.SetReplyTo(reply_to);
 
+				// getting signature.
+				CString signature;
+				g_file2cstring(app->m_app_path+"\\"+current_account+"\\signature", signature);
+				// set main text.
+				app->m_me.AddText(signature);
+				// draftframe
+				app->CreateDraftFrame(mf->m_pAcntV->GetCurrentAccountName());
+			}else if(link.Find("@") != -1){
+
+				// initialization.
+				app->m_me.Initialize();
+				// setting To
+				app->m_me.SetTo(link);
+
+				// setting From
+				CString path = app->m_app_path+"\\"+current_account+"\\account.ini";
+				CString address;
+				GetPrivateProfileString("mailbox", "address", "", address.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+				address.ReleaseBuffer();
+				app->m_me.SetFrom(address);
+
+				// setting "cc"
+				CString cc;
+				GetPrivateProfileString("def_address", "cc", "", cc.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+				cc.ReleaseBuffer();
+				app->m_me.SetCc(cc);
+
+				// setting "bcc"
+				CString bcc;
+				GetPrivateProfileString("def_address", "bcc", "", bcc.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+				bcc.ReleaseBuffer();
+				app->m_me.SetBcc(bcc);
+
+				// setting "reply-to"
+				CString reply_to;
+				GetPrivateProfileString("def_address", "reply_to", "", reply_to.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+				reply_to.ReleaseBuffer();
+				app->m_me.SetReplyTo(reply_to);
+
 				// getting signature.
 				CString signature;
 				g_file2cstring(app->m_app_path+"\\"+current_account+"\\signature", signature);
@@ -427,52 +506,40 @@ void CTextView::DisplayPart(int part)
 	CMainFrame *mf = (CMainFrame*)app->m_pMainWnd;
 	CStringArray body;
 	CString message;
+	CString out;
 	CString header;
 	CString tmp;
 	CTemplate tmpl;
+	CCodeConvert cc;
 
 	m_current_part = part;
 	m_md.GetBody(part, body);
-	g_cstra2cstr(body, message, g_cstra_getsize(body));
+	g_cstringarray2cstring(body, message);
 
 	if(m_md.GetFileName(part).IsEmpty()){
 		// in case of base64 in text/plain or text/html.
 		if(m_md.GetEncodingType(part) == BASE64){
 			message.Remove('\r');
 			message.Remove('\n');
-			char* in_base64 = message.GetBuffer(0);
-			char* out_base64 = new char[message.GetLength() + 1];
-			int len = from64tobits(out_base64, in_base64, strlen(in_base64));
-			out_base64[len] = 0;
+			g_decode_base64(message, out);
 			message.Empty();
-			message = out_base64;
-			delete[] out_base64;
+			message = out;
 		}
 		// in case of quoted-printable in text/plain or text/html
 		if(m_md.GetEncodingType(part) == QUOTED_PRINTABLE){
-			// fromQPtobits̎₵
-			// implementation of fromQPtobits is weird.
-			char* in_qp = message.GetBuffer(0);
-			char* out_qp = new char[message.GetLength()+10]; // łbuffer̗eʂȂ݂ŎXꂪłSȂɂȂ邱ƂBBB 
-			// +10fromQPtobits̍Ōő}NULL 
-			// +10 mean fromQPtobits insert NULL last.
-			// CString  GetBuffer NULL͊܂܂Ȃ̂HHHH 
-			// not clear that CString::GetBuffer not include NULL ?????
-			int len = fromQPtobits(out_qp, in_qp, strlen(in_qp));
-			out_qp[len] = 0;
+			g_decode_qp(message, out);
 			message.Empty();
-			message = out_qp;
-			delete[] out_qp;
+			message = out;
 		}
-		CCodeConvert cc(message);
+		cc.SetString(message);
 		message = cc.ToSjis();
 	}else{ // in case of attachment file.
 		if(GetCurrentCTE() == SEVEN_BIT){
-			CCodeConvert cc(message);
+			cc.SetString(message);
 			message = cc.ToSjis();
 		}
 		else if(GetCurrentCTE() == EIGHT_BIT){
-			CCodeConvert cc(message);
+			cc.SetString(message);
 			message = cc.ToSjis();
 		}else{
 			message.Format("Ytt@C\r\n%s", m_md.GetFileName(part));
@@ -510,10 +577,13 @@ void CTextView::DisplayPart(int part)
 	GetRichEditCtrl().HideSelection(TRUE, FALSE);
 	GetRichEditCtrl().SetSel(0, 0);*/
 	this->SetFontColorAndLink();
+
+	app->m_pluginManager.OnTextViewChanged(true);
 }
 
 void CTextView::Update(CString path)
 {
+	CWaitCursor wait_cursor; // turn cursor into sandglass
 	CPochyApp *app = (CPochyApp *)AfxGetApp();
 	CMainFrame *mf = (CMainFrame*)app->m_pMainWnd;
 	CListCtrl &lc = mf->m_pMultiV->GetListCtrl();
@@ -523,6 +593,7 @@ void CTextView::Update(CString path)
 	// after getting 0st element of MULTIPARTSTRUCT in mimedecode class, and display.
 	if(path.IsEmpty()){ // if empty, not display. 
 		this->Clear();
+		return;
 	}else{
 		if(!m_md.DoIt(path)){ // analyze mime structure of mail.
 			this->Clear();
@@ -542,10 +613,10 @@ void CTextView::Update(CString path)
 		// setting multipartview
 		lc.DeleteAllItems();
 		int n;
-		if(1 < m_md.HowManyPart()){ // in case of two or more than tree multipart.
-			n = 0;
+		int max=m_md.HowManyPart();
+		if(1 < max){ // in case of two or more than tree multipart.
 			CString enc_type;
-			while(n < m_md.HowManyPart()){
+			for(n=0; n<max; n++){
 				lc.InsertItem(n, m_md.GetContentType(n));
 				switch(m_md.GetEncodingType(n)){
 				case BASE64:
@@ -557,22 +628,39 @@ void CTextView::Update(CString path)
 				case SEVEN_BIT:
 					enc_type = "7bit";
 					break;
+				case EIGHT_BIT:
+					enc_type = "8bit";
+					break;
 				}
 				lc.SetItemText(n, 1, enc_type);
 				if(!m_md.GetFileName(n).IsEmpty()){
 					lc.SetItemText(n, 2, m_md.GetFileName(n));
 				}
-				n++;
 			}
 			mf->HideMultiPartView(FALSE);
 			// setting 0th item selected.
 			lc.SetItemState(0, LVIS_SELECTED | LVIS_FOCUSED, LVIS_SELECTED | LVIS_FOCUSED);
 		}
 		else if(!m_md.GetFileName(0).IsEmpty()){ // in case of only one attachment file.
-			lc.InsertItem(0, m_md.GetFileName(0));
-
+			CString enc_type;
+			lc.InsertItem(0, m_md.GetContentType(0));
+			switch(m_md.GetEncodingType(0)){
+			case BASE64:
+				enc_type = "base64";
+				break;
+			case QUOTED_PRINTABLE:
+				enc_type = "quoted-printable";
+				break;
+			case SEVEN_BIT:
+				enc_type = "7bit";
+				break;
+			}
+			lc.SetItemText(0, 1, enc_type);
+			if(!m_md.GetFileName(0).IsEmpty()){
+				lc.SetItemText(0, 2, m_md.GetFileName(0));
+			}
 			mf->HideMultiPartView(FALSE);
-			// setting item of 0 selected.
+			// setting 0th item selected.
 			lc.SetItemState(0, LVIS_SELECTED | LVIS_FOCUSED, LVIS_SELECTED | LVIS_FOCUSED);
 		}
 		else{ // in case of not multipart, nor number of multipart is one, text/html
@@ -585,6 +673,7 @@ void CTextView::Update(CString path)
 
 void CTextView::Update2(CString mail)
 {
+	CWaitCursor wait_cursor; // turn cursor into sandglass
 	CPochyApp *app = (CPochyApp *)AfxGetApp();
 	CMainFrame *mf = (CMainFrame*)app->m_pMainWnd;
 	CListCtrl &lc = mf->m_pMultiV->GetListCtrl();
@@ -612,10 +701,10 @@ void CTextView::Update2(CString mail)
 		// multipartview ̐ݒ
 		lc.DeleteAllItems();
 		int n;
-		if(1 < m_md.HowManyPart()){ // multipart2ȏ̏ꍇ
-			n = 0;
+		int max = m_md.HowManyPart();
+		if(1 < max){ // multipart2ȏ̏ꍇ
 			CString enc_type;
-			while(n < m_md.HowManyPart()){
+			for(n=0; n<max; n++){
 					lc.InsertItem(n, m_md.GetContentType(n));
 					switch(m_md.GetEncodingType(n)){
 					case BASE64:
@@ -627,10 +716,12 @@ void CTextView::Update2(CString mail)
 					case SEVEN_BIT:
 						enc_type = "7bit";
 						break;
+					case EIGHT_BIT:
+						enc_type = "8but";
+						break;
 					}
 					lc.SetItemText(n, 1, enc_type);
 					lc.SetItemText(n, 2, m_md.GetFileName(n));
-				n++;
 			}
 			mf->HideMultiPartView(FALSE);
 			// 0Ԗڂ̃ACeIԂɂ
@@ -668,7 +759,11 @@ void CTextView::OnRButtonDown(UINT nFlags, CPoint point)
 	else
 		menu.EnableMenuItem(ID_TEXTVIEW_COPY, MF_ENABLED /* L */);
 
-	// htmltextbinaryf
+	CPochyApp* pPochyApp = (CPochyApp*)::AfxGetApp();
+	if (pPochyApp != NULL)
+	{
+		pPochyApp->m_pluginManager.OnInitMenu(menu.GetSubMenu(0)->GetSafeHmenu(), POCHY_MENU_TEXT_VIEW);
+	}
 
 	CMenu *pPopup = menu.GetSubMenu(0);
 	pPopup->TrackPopupMenu(TPM_LEFTALIGN | TPM_RIGHTBUTTON, (int)pt.x, (int)pt.y, this);
@@ -693,52 +788,45 @@ void CTextView::OnPopupBrowser()
 {
 	CPochyApp *app = (CPochyApp *)AfxGetApp();
 	CStringArray body;
+	CString out;
 
 	if(this->m_current_part == -1) return;
 
 	this->m_md.GetBody(this->m_current_part, body);
 
 	CString buf;
-	g_cstra2cstr(body, buf, g_cstra_getsize(body));
+	g_cstringarray2cstring(body, buf);
 
 	if(this->m_md.GetEncodingType(this->m_current_part) == BASE64){
 		buf.Remove('\r');
 		buf.Remove('\n');
-		char* in_base64 = buf.GetBuffer(0);
-		char* out_base64 = new char[buf.GetLength() + 1];
-		int len = from64tobits(out_base64, in_base64, strlen(in_base64));
-		out_base64[len] = 0;
+		g_decode_base64(buf, out);
 		buf.Empty();
-		buf = out_base64;
-		delete[] out_base64;
+		buf = out;
 	}
 	// in case of quoted-printable in text/plain or text/html
 	else if(this->m_md.GetEncodingType(this->m_current_part) == QUOTED_PRINTABLE){
-		// fromQPtobits̎₵
-		// implementation of fromQPtobits is weird.
-		char* in_qp = buf.GetBuffer(0);
-		char* out_qp = new char[buf.GetLength()+10]; // łbuffer̗eʂȂ݂ŎXꂪłSȂɂȂ邱ƂBBB 
-		// +10fromQPtobits̍Ōő}NULL 
-		// +10 mean fromQPtobits insert NULL last.
-		// CString  GetBuffer NULL͊܂܂Ȃ̂HHHH 
-		// not clear that CString::GetBuffer not include NULL ?????
-		int len = fromQPtobits(out_qp, in_qp, strlen(in_qp));
-		out_qp[len] = 0;
+		g_decode_qp(buf, out);
 		buf.Empty();
-		buf = out_qp;
-		delete[] out_qp;
+		buf = out;
 	}
 
 	CString msg_id;
 	// use Message-ID for file name
 	msg_id = m_md.m_hi.GetMsgID();
 	msg_id = g_ma(msg_id);
-	msg_id.Replace(".", "_");
+	msg_id.Remove('.');
+	msg_id.Remove('/');
+	msg_id.Remove(':');
+	msg_id.Remove('*');
+	msg_id.Remove('?');
+	msg_id.Remove('\"');
+	msg_id.Remove('|');
 
 	if(!g_is_there(app->m_app_path+"\\temp")) // if temp directory not exist, create
 		_mkdir(app->m_app_path+"\\temp");
 
-	g_cstring2file(buf, app->m_app_path+"\\temp\\"+msg_id+".html");
+	g_string2file(buf, app->m_app_path+"\\temp\\"+msg_id+".html");
 	CString strBrowserPath = app->GetProfileString(_T("Customize"), _T("BrowserPath"), _T(""));
 	if (strBrowserPath != _T(""))
 	{
@@ -759,13 +847,19 @@ void CTextView::OnPopupEditor()
 	// user Message-ID for file name
 	msg_id = m_md.m_hi.GetMsgID();
 	msg_id = g_ma(msg_id);
-	msg_id.Replace(".", "_");
+	msg_id.Remove('.');
+	msg_id.Remove('/');
+	msg_id.Remove(':');
+	msg_id.Remove('*');
+	msg_id.Remove('?');
+	msg_id.Remove('\"');
+	msg_id.Remove('|');
 
 	if(!g_is_there(app->m_app_path+"\\temp")) // if temp directory not exist, create
 		_mkdir(app->m_app_path+"\\temp");
 
 	FILE* file = fopen(app->m_app_path+"\\temp\\"+msg_id+".txt", "wb");
-	fwrite(body.GetBuffer(0), sizeof(char), body.GetLength(), file);
+	fwrite(body, sizeof(char), body.GetLength(), file);
 	fclose(file);
 
 	CString file_path = app->m_app_path+"\\temp\\"+msg_id+".txt";
@@ -810,13 +904,11 @@ void CTextView::SetFontColorAndLink()
 		app->GetProfileInt("TextViewColor", "TxtColorG", DEF_TXT_COLOR_G),
 		app->GetProfileInt("TextViewColor", "TxtColorB", DEF_TXT_COLOR_B));
 	cf.dwEffects = CFE_PROTECTED | CFE_SUBSCRIPT;
-//	cf.bCharSet = CHINESEBIG5_CHARSET;
-//	strcpy(cf.szFaceName, "MingLiU");//cf.szFaceName
-//	r.SendMessage(EM_SETCHARFORMAT,(WPARAM)SCF_ALL,(LPARAM)&cf);
+	r.HideSelection(TRUE, FALSE);
 	r.SetSel(0, -1);
 	r.SetSelectionCharFormat(cf);
-	r.HideSelection(TRUE, FALSE);
 	r.SetSel(0, 0);
+	r.HideSelection(FALSE, FALSE);
 
 	// if header view is not active, set header charactor color.
 	if(!app->GetProfileInt("Customize", "HeaderView", 1)){
@@ -825,6 +917,7 @@ void CTextView::SetFontColorAndLink()
 		ft.chrg.cpMax = -1;
 		ft.lpstrText = _T("\r\r");
 		long pos = r.FindText(FR_DOWN, &ft);
+		r.HideSelection(TRUE, FALSE);
 		r.SetSel(0, pos);
 		r.GetSelectionCharFormat(cf);
 		cf.dwMask = CFM_COLOR | CFM_BACKCOLOR;
@@ -833,9 +926,37 @@ void CTextView::SetFontColorAndLink()
 			app->GetProfileInt("TextViewHdColor", "TxtColorG", DEF_HEADER_INFO_COLOR_G),
 			app->GetProfileInt("TextViewHdColor", "TxtColorB", DEF_HEADER_INFO_COLOR_B));
 		r.SetSelectionCharFormat(cf);
-		r.HideSelection(TRUE, FALSE);
 		r.SetSel(0, 0);
+		r.HideSelection(FALSE, FALSE);
 	}
+
+/*	regex_t reg;
+	regmatch_t pmatch[2]; 
+	CString regex = "[a-z0-9\.\_\-]+@[a-z0-9\.\_\-]+";
+	regcomp(&reg, regex, REG_EXTENDED | REG_NEWLINE | REG_ICASE);
+
+	this->GetRichEditCtrl().GetSelectionCharFormat(cf);
+	cf.dwMask = CFM_LINK;
+	cf.dwEffects = CFE_LINK;
+
+	int start, end, len = 0;
+	CString buf= this->m_text;
+	CString buf2 = buf;
+	for(;;){
+		if(!regexec(&reg, buf2, 2, pmatch, 0)){
+			start = g_richedit_count_char(buf.Left(len+pmatch[0].rm_so));
+			end = g_richedit_count_char(buf.Left(len+pmatch[0].rm_eo));
+			this->GetRichEditCtrl().SetSel(start, end);
+			this->GetRichEditCtrl().SetSelectionCharFormat(cf);
+			this->GetRichEditCtrl().HideSelection(TRUE, FALSE);
+			this->GetRichEditCtrl().SetSel(0, 0);
+			len += pmatch[0].rm_eo+1;
+			buf2 = buf2.Mid(pmatch[0].rm_eo+1);
+		}else{
+			break;
+		}
+	}
+	regfree(&reg);*/
 }
 
 void CTextView::ReDisplay()
@@ -865,6 +986,7 @@ void CTextView::Clear()
 	this->m_path.Empty();
 
 	mf->HideMultiPartView(TRUE);
+	app->m_pluginManager.OnTextViewChanged(false);
 }
 
 BOOL CTextView::PreCreateWindow(CREATESTRUCT& cs) 
@@ -891,8 +1013,13 @@ void CTextView::OnPageUp()
 	}
 }
 
+void CTextView::OnPageDown()
+{
+	PageDown();
+}
+
 // page down Ƃ true Ԃ
-bool CTextView::OnPageDown()
+BOOL CTextView::PageDown()
 {
 	bool bPageDowned = false;
 
@@ -913,7 +1040,7 @@ bool CTextView::OnPageDown()
 
 void CTextView::OnScrollAndNextUnread()
 {
-	if (!OnPageDown())
+	if (!PageDown())
 	{
 		CPochyApp* pApp = (CPochyApp*)::AfxGetApp();
 		CMainFrame* pMainFrame = (CMainFrame*)pApp->m_pMainWnd;
@@ -937,3 +1064,18 @@ int CTextView::GetLastVisibleLine()
 
 	return nLastVisibleLine;
 }
+
+BOOL CTextView::OnCommand(WPARAM wParam, LPARAM lParam) 
+{
+	CPochyApp *pPochyApp = (CPochyApp *)AfxGetApp();
+	if (pPochyApp != NULL)
+	{
+		CMainFrame *pMainFrame = (CMainFrame*)pPochyApp->m_pMainWnd;
+		if (pMainFrame != NULL)
+		{
+			pMainFrame->CallPluginCallback(this->GetSafeHwnd(), LOWORD(wParam));
+		}
+	}
+	
+	return CBitmapRichEditView::OnCommand(wParam, lParam);
+}
