@@ -27,8 +27,6 @@ public:
 	CString m_text;				// ݕ\Ăei[
 	CString m_path;				// [i[t@C̃tpX
 	CString m_display_header;	// TextViewɕ\Ƃ̖{ɂ镔
-	long m_onlink;				// OnLinkdɌĂ΂̋̑΍iƂ낪NbNꂽXj
-	CFont m_font;				// tHgi[
 
 // Iy[V
 public:
@@ -68,6 +66,7 @@ public:
 	protected:
 	virtual void OnDraw(CDC* pDC);      // ̃r[`悷邽߂ɃI[o[Ch܂B
 	virtual BOOL PreCreateWindow(CREATESTRUCT& cs);
+	virtual BOOL OnCommand(WPARAM wParam, LPARAM lParam);
 	//}}AFX_VIRTUAL
 
 // Cve[V
@@ -88,13 +87,17 @@ protected:
 	afx_msg void OnPopupEditor();
 	afx_msg void OnSetFocus(CWnd* pOldWnd);
 	afx_msg void OnPageUp();
-	afx_msg bool OnPageDown();
+	afx_msg void OnPageDown();
 	afx_msg void OnScrollAndNextUnread();
 	//}}AFX_MSG
 	DECLARE_MESSAGE_MAP()
 private:
+	BOOL PageDown();
 	int GetLastVisibleLine();
 	CString m_header_template;
+	CFont m_font;				// tHgi[
+	long m_onlink;				// OnLinkdɌĂ΂̋̑΍iƂ낪NbNꂽXj
+
 };
 
 /////////////////////////////////////////////////////////////////////////////
