@@ -3,18 +3,7 @@
  *
  * For license terms, see the file COPYING in this directory.
  */
-/*
-#include  "config.h"
-#include  <stdio.h>
-#include  <string.h>
-#include  <ctype.h>
-#if defined(STDC_HEADERS)
-#include  <stdlib.h>
-#endif
-#include  "fetchmail.h"
-#include  "socket.h"
 
-#include  "i18n.h"*/
 #include "stdafx.h"
 #include "Pochy.h"
 #include "md5.h"
