@@ -14,80 +14,63 @@
 #include "_regex.h" // K\֐
 #include "process.h" // getpid()
 #include "base64.h"
+#include "quoted-printable.h"
 
-void g_log(CString path, CString log)
+void g_log(LPCTSTR log, LPCTSTR path)
 {
-	CPochyApp *app = (CPochyApp*)AfxGetApp();
 	FILE* file;
-	if((file = fopen(app->m_app_path+"\\"+path, "ab"))==NULL){
-		AfxMessageBox("fopen: error at g_log");
+	if((file = fopen(path, "ab"))==NULL){
 		return;
 	}
-	fwrite(log, sizeof(char), log.GetLength(), file);
+	fwrite(log, sizeof(char), strlen(log), file);
 	fclose(file);
 }
 
-// cdr֐
-BOOL g_cstr_compare(LPCTSTR c, LPCTSTR d)
+// 啶Ɋ֌WȂcdr֐
+BOOL g_string_compare_no_case(LPCTSTR c, LPCTSTR d)
 {
-	regex_t reg; // K\i[p
-	regmatch_t pmatch[2]; // regexečʂi[
+	CString tmp1 = c;
+	CString tmp2 = d;
 
-	CString regex;
-	regex.Format("^%s$", c);
-	regcomp(&reg, regex.GetBuffer(0), REG_EXTENDED | REG_NEWLINE | REG_ICASE |REG_NOSUB );
-	if(0 == regexec(&reg, d, 2, pmatch, 0)){
-		regfree(&reg);
+	if(tmp1.CompareNoCase(tmp2) == 0)
 		return TRUE;
-	}
-	regfree(&reg);
+
 	return FALSE;
 }
 
-BOOL g_rm_recursive(CString path)
+BOOL g_rm_recursive(LPCTSTR path)
 {
 	CFileFind ff;
 	BOOL b_Find;
-	CString cPath = path + "\\*.*";
+	CString tmp = path;
 
-	b_Find = ff.FindFile(cPath);
+	b_Find = ff.FindFile(tmp + "\\*.*");
 	while(b_Find){
 		b_Find = ff.FindNextFile();
 		if(ff.IsDots())
 			continue;
 		if(ff.IsDirectory()){
-			if(!g_rm_recursive(path + "\\" + ff.GetFileName()))
+			if(!g_rm_recursive(tmp + "\\" + ff.GetFileName()))
 				return FALSE;
 		}else{
-			if(!DeleteFile(path + "\\" +ff.GetFileName()))
+			if(!DeleteFile(tmp + "\\" +ff.GetFileName()))
 				return FALSE;
 		}
 	}
-	ff.FindFile(cPath + "\\.."); // JgfBNgύXĂȂrmdirłȂ
+	ff.FindFile(tmp + "\\.."); // JgfBNgύXĂȂrmdirłȂ
 	if(_rmdir(path))
 		return FALSE;
 	return TRUE;
 }
 
 // CStringt@CփeLXgo֐
-BOOL g_cstring2file(/*CString& buf*/LPCTSTR buf, LPCTSTR file_name)
+BOOL g_string2file(/*CString& buf*/LPCTSTR buf, LPCTSTR file_name)
 {
-/*	HANDLE hTmp;
-	DWORD len;
-	hTmp = CreateFile(filename,GENERIC_WRITE,0,NULL,OPEN_ALWAYS,FILE_ATTRIBUTE_NORMAL,NULL);
-*/
-//	WriteFile(hTmp, buf, /*buf.GetLength()*/strlen(buf), &len, 0);
-/*	if(!CloseHandle(hTmp)){
-		AfxMessageBox("CloseHandle");
-		return FALSE;
-	}
-	return TRUE;*/
-
 	FILE *fp;
 
 	fp = fopen(file_name, "wb");
 	if(0 > fwrite(buf, sizeof(char), strlen(buf), fp)){
-		AfxMessageBox("g_cstring2file error");
+		AfxMessageBox("g_string2file error");
 		fclose(fp);
 		return FALSE;
 	}
@@ -97,10 +80,10 @@ BOOL g_cstring2file(/*CString& buf*/LPCTSTR buf, LPCTSTR file_name)
 }
 
 // t@CCStringɃeLXgo֐
-BOOL g_file2cstring(LPCTSTR filename,CString& buf)
+BOOL g_file2cstring(LPCTSTR path,CString& buf)
 {
 	CFile file;
-	if(!file.Open(filename,CFile::modeRead)){
+	if(!file.Open(path, CFile::modeRead)){
 		return FALSE;
 	}
 	LPSTR pbuf;
@@ -113,7 +96,7 @@ BOOL g_file2cstring(LPCTSTR filename,CString& buf)
 }
 
 // t@C쐬֐
-BOOL g_fcreate(LPCTSTR path)
+BOOL g_file_create(LPCTSTR path)
 {
 	HANDLE h = CreateFile(
 		path,
@@ -186,7 +169,8 @@ BOOL g_connect_process(CStringArray &comline, CString &out1, CString &out2)
 	}
 
 	// ͂
-	for(int i=1;i<comline.GetSize();i++){
+	int max = comline.GetSize();
+	for(int i=1; i<max; i++){
 		DWORD len;
 		WaitForInputIdle(pi.hProcess,INFINITE);
 		WriteFile(hInputWrite,comline[i],comline[i].GetLength(),&len,NULL);
@@ -240,60 +224,36 @@ BOOL g_connect_process(CStringArray &comline, CString &out1, CString &out2)
 	return TRUE;
 }
 
-/*
-int g_get_icon_index(const CString& csFileName)
-{
-	SHFILEINFO sfi;
-
-	SHGetFileInfo(
-		(LPCTSTR)csFileName, 
-		0,
-		&sfi, 
-		sizeof(SHFILEINFO), 
-		SHGFI_USEFILEATTRIBUTES | SHGFI_SYSICONINDEX | SHGFI_SMALLICON);
-
-	return sfi.iIcon;
-}
-*/
-
-// CStringesCStringArrayɊi[isep܂߂j
-void g_cstr2cstra(CString& cstr, CStringArray& cstra, LPCTSTR sep)
+// put each part separated with sep into CStringArray
+void g_string2cstringarray(LPCTSTR string, CStringArray& array, LPCTSTR sep, BOOL include_sep)
 {
 	int a;
-	cstra.RemoveAll();
-	a = cstr.Find(sep);
-	while(a!=-1){
-		cstra.Add(cstr.Left(a+strlen(sep)));
-		cstr = cstr.Mid(a+strlen(sep));
-		a = cstr.Find(sep);
-	}
-	cstra.Add(cstr);
-}
+	CString tmp = string;
 
-// CStringesCStringArrayɊi[isep͊܂߂Ȃj
-void g_cstr2cstra_ex(CString& cstr, CStringArray& cstra, LPCTSTR sep)
-{
-	CString buf;
-	int a;
-	cstra.RemoveAll();
-	a = cstr.Find(sep);
+	array.RemoveAll();
+	a = tmp.Find(sep);
 	while(a!=-1){
-		buf = cstr.Left(a);
-		cstra.Add(buf);
-		cstr = cstr.Mid(a+strlen(sep));
-		a = cstr.Find(sep);
+		if(include_sep){
+			array.Add(tmp.Left(a+strlen(sep)));
+		}else{
+			array.Add(tmp.Left(a));
+		}
+		tmp = tmp.Mid(a+strlen(sep));
+		a = tmp.Find(sep);
 	}
-	cstra.Add(cstr);
+	array.Add(tmp);
 }
 
 // CStringArrayɊesi[̂CStringɏo
-void g_cstra2cstr(CStringArray& cstra, CString& cstr, int size)
+void g_cstringarray2cstring(CStringArray& cstra, CString& cstr)
 {
 	int i;
+	int max;
 	cstr.Empty();
 
-	char *p = cstr.GetBuffer(size);
-	for(i=0;i<cstra.GetSize();i++){
+	char *p = cstr.GetBuffer(g_cstringarray_getsize(cstra));
+	max = cstra.GetSize();
+	for(i=0; i<max; i++){
 		strcpy(p, cstra.GetAt(i));
 		p += cstra.GetAt(i).GetLength();
 	}
@@ -301,50 +261,68 @@ void g_cstra2cstr(CStringArray& cstra, CString& cstr, int size)
 }
 
 // CStringArrayɊi[ꂽCStringS̃TCY
-int g_cstra_getsize(CStringArray& cstra)
+int g_cstringarray_getsize(CStringArray& cstra)
 {
 	int i;
 	int n;
+	int max;
 
-	i = n = 0;
-	while(i < cstra.GetSize()){
+	n = 0;
+	max = cstra.GetSize();
+	for(i=0; i<max; i++){
 		n += cstra.GetAt(i).GetLength();
-		i++;
 	}
 	return n;
 }
 
 // eLXgt@C̊esCStringArrayɓǂݍ
-BOOL g_file2cstra(LPCTSTR path, CStringArray &cstra)
+BOOL g_file2cstringarray(LPCTSTR path, CStringArray &cstra)
 {
 	CString buf;
 	CStdioFile file;
+	int i;
+
+	cstra.RemoveAll();
+	cstra.SetSize(1000);
 
 	if(!file.Open(path, CFile::modeRead | CFile::typeText))
 		return FALSE;
-	while(file.ReadString(buf)){
+
+	for(i=0; file.ReadString(buf); i++){
+		if(i == cstra.GetSize()){
+			cstra.SetSize(cstra.GetSize()+100);
+		}
 		buf += "\r\n";
-		cstra.Add(buf);
+		cstra.SetAt(i, buf);
 	}
-	buf.Empty();
 	file.Close();
+
+	for(i=cstra.GetSize()-1; i>=0; i--){
+		if(cstra[i].IsEmpty()){
+			cstra.RemoveAt(i);
+		}else{
+			break;
+		}
+	}
+
 	return TRUE;
 }
 
 // CStringArrayɊesi[ꂽeLXgt@C֏o
-BOOL g_cstra2file(LPCTSTR path, CStringArray &cstra)
+BOOL g_cstringarray2file(LPCTSTR path, CStringArray &cstra)
 {
-	int n = 0;
+	int n;
+	int max;
 	FILE *file;
 
 	file = fopen(path, "wb");
 	if(file == NULL){
-		AfxMessageBox("fopen: error");
+		AfxMessageBox("g_cstringarray2file error");
 		return FALSE;
 	}
-	while(n < cstra.GetSize()){
+	max = cstra.GetSize();
+	for(n=0; n<max; n++){
 		fwrite(cstra.GetAt(n), sizeof(char), cstra.GetAt(n).GetLength(), file);
-		n++;
 	}
 	fclose(file);
 
@@ -352,7 +330,7 @@ BOOL g_cstra2file(LPCTSTR path, CStringArray &cstra)
 }
 
 // t@C̑傫Ԃ
-long g_getfs(LPCTSTR path)
+long g_get_file_size(LPCTSTR path)
 {
 	FILE *file;
 	long size = 0;
@@ -369,31 +347,13 @@ long g_getfs(LPCTSTR path)
 
 // t@CԍƂČƂA
 // (num)ȏł܂݂Ȃŏ̔ԍԂ֐
-int g_get_min_num(CString path)
+int g_get_min_num(LPCTSTR path)
 {
-/*	CString cNum;
-	CString tmp;
-	HANDLE hFile;
-	WIN32_FIND_DATA wfd;
-
-	while(1){
-		tmp = path;
-		cNum.Format("\\%d", num);
-		tmp += cNum;
-		cNum.Empty();
-		hFile = FindFirstFile(tmp.GetBuffer(0), &wfd);
-		tmp.Empty();
-		if(hFile == INVALID_HANDLE_VALUE) break;
-		num++;
-	}
-	FindClose(hFile);
-
-	cNum.Format("%d", num);
-	return num;*/
+	CString tmp = path;
 
 	int i=0;
 	CFileFind ff;
-	BOOL b = ff.FindFile(path+"\\*.*");
+	BOOL b = ff.FindFile(tmp+"\\*.*");
 	while(b){
 		b = ff.FindNextFile();
 		if(	!ff.IsDirectory() &&
@@ -409,7 +369,7 @@ int g_get_min_num(CString path)
 }
 
 // CStringAray̕o֐
-void g_cstra_getpart(CStringArray &org, CStringArray &dst, int start, int end)
+void g_cstringarray_getpart(CStringArray &org, CStringArray &dst, int start, int end)
 {
 	dst.RemoveAll();
 
@@ -435,45 +395,30 @@ BOOL g_is_there(LPCTSTR path)
 }
 
 // <>̒̕Ԃ֐
-CString g_ma(CString& to)
+CString g_ma(LPCTSTR to)
 {
-	CString res;
+	CString tmp1 = to;
+	CString tmp2;
+
 	int p,p2,q,q2;
-	p = to.Find("<")+1;
-	q = to.Find(">")+1;
-	p2 = to.Find("<",p)+1;
-	q2 = to.Find(">",q)+1;
+	p = tmp1.Find("<")+1;
+	q = tmp1.Find(">")+1;
+	p2 = tmp1.Find("<",p)+1;
+	q2 = tmp1.Find(">",q)+1;
 
-	if(p && q && !p2 && !q2)
-		return to.Mid(p,q-p-1);
-	if(p || q || p2 || q2)
-		AfxMessageBox(to+"\r\n͕ςȃAhXłB");
-	return to;
-}
-
-CString g_getfield(CString& body,LPCTSTR name)
-{
-	CString res;
-	int a,b;
-	a = body.Find(name);
-	if(a==-1){
-		res.Empty();
-		return res;
+	if(p && q && !p2 && !q2){
+		tmp2 = tmp1.Mid(p,q-p-1);
+		return tmp2;
 	}
-	if(a==0 || body[a-1]==10){
-		b = body.Find("\r\n",a);
-		if(b == -1)
-			b = body.GetLength();
-		a += strlen(name);
-		res = body.Mid(a,b-a);
+	if(p && q && (p2 || q2)){
+		tmp2.Empty();
+		return tmp2;
 	}
-	res.TrimLeft();
-	res.TrimRight();
-	return res;
+	return tmp1;
 }
 
 // Message-ID𐶐֐
-CString g_gen_msgid(CString from)
+CString g_gen_msgid(LPCTSTR from)
 {
 	CString message_id;
 	CTime t = CTime::GetCurrentTime();
@@ -489,37 +434,13 @@ CString g_gen_msgid(CString from)
 	return message_id;
 }
 
-void g_cstr_chop(CString &buf)
+void g_cstring_chop(CString &buf)
 {
 	if(buf.IsEmpty()) return;
 	buf.TrimRight("\r\n");
 	buf.TrimLeft("\t ");
 }
 
-CString g_cstr_chop2(CString buf)
-{
-	if(buf.IsEmpty()) return buf;
-	buf.TrimRight("\r\n");
-	buf.TrimLeft("\t ");
-	return buf;
-}
-
-int g_cstr_rvs_find(CString org, LPCTSTR key, int start)
-{
-	int i=start;
-
-	if(i >= org.GetLength())
-		return -1;
-
-	while(i > 0){
-		if(org.GetAt(i) == (TCHAR)key)
-			return i;
-
-		i--;
-	}
-	return -1;
-}
-
 // e|[t@C쐬Ãt@Cւ̃pXԂ
 CString g_get_tmp_file()
 {
@@ -577,96 +498,8 @@ void g_logfont_copy(LOGFONT *dst, LOGFONT *org)
 	dst->lfWidth				= org->lfWidth;
 }
 
-// timezone name ^ƁAtimezone offsetԂ֐
-CString g_get_tzoffset_from_tzname(CString name)
-{
-
-	name.MakeUpper();
-
-	CMapStringToString map;
-
-	map.SetAt("NZDT",	"+1300");	// New Zealand Daylight Time (j[W[hĎ)
-	map.SetAt("IDLE",	"+1200");	// International Date Line, East (ۓtύXA)
-	map.SetAt("NZST",	"+1200");	// New Zealand Std Time (j[W[hW)
-	map.SetAt("NZT",	"+1200");	// New Zealand Time (j[W[h)
-	map.SetAt("AESST",	"+1100");	// Australia Eastern Summer Std Time (I[XgAWĎ)
-	map.SetAt("ACSST",	"+1030");	// Central Australia Summer Std Time (I[XgAWĎ)
-	map.SetAt("CADT",	"+1030");	// Central Australia Daylight Savings Time (I[XgAĎ)
-	map.SetAt("SADT",	"+1030");	// South Australian Daylight Time (I[XgA암Ď)
-	map.SetAt("AEST",	"+1000");	// Australia Eastern Std Time (I[XgAW)
-	map.SetAt("EAST",	"+1000");	// East Australian Std Time (I[XgAW)
-	map.SetAt("GST",	"+1000");	// Guam Std Time, USSR Zone 9 (OAWԁA\rGg^C][ 9)
-	map.SetAt("LIGT",	"+1000");	// Melbourne, Australia (I[XgAA{)
-	map.SetAt("ACST",	"+0930");	// Central Australia Std Time (I[XgAW)
-	map.SetAt("CAST",	"+0930");	// Central Australia Std Time (I[XgAW)
-	map.SetAt("SAT",	"+0930");	// South Australian Std Time (I[XgA암W)
-	map.SetAt("AWSST",	"+0900");	// Australia Western Summer Std Time (I[XgAW)
-	map.SetAt("JST",	"+0900");	// Japan Std Time, USSR Zone 8 ({WԁA\rGg^C][ 8)
-	map.SetAt("KST",	"+0900");	// Korea Standard Time (؍W)
-	map.SetAt("WDT",	"+0900");	// West Australian Daylight Time (I[XgAĎ)
-	map.SetAt("MT",		"+0830");	// Moluccas Time (bJ)
-	map.SetAt("AWST",	"+0800");	// Australia Western Std Time (I[XgAW)
-	map.SetAt("CCT",	"+0800");	// China Coastal Time (pݎ)
-	map.SetAt("WADT",	"+0800");	// West Australian Daylight Time (A[XgAĎ)
-	map.SetAt("WST",	"+0800");	// West Australian Std Time (I[XgAW)
-	map.SetAt("JT",		"+0730");	// Java Time (Java )
-	map.SetAt("WAST",	"+0700");	// West Australian Std Time (I[XgAW)
-	map.SetAt("IT",		"+0330");	// Iran Time (C)
-	map.SetAt("BT",		"+0300");	// Baghdad Time (oO_bh)
-	map.SetAt("EETDST",	"+0300");	// Eastern Europe Daylight Savings Time ([bpĎ)
-	map.SetAt("CETDST",	"+0200");	// Central European Daylight Savings Time ([bpĎ)
-	map.SetAt("EET",	"+0200");	// Eastern Europe, USSR Zone 1 ([bpԁA\rGg^C][ 1)
-	map.SetAt("FWT",	"+0200");	// French Winter Time (tX~)
-	map.SetAt("IST",	"+0200");	// Israel Std Time (CXGW)
-	map.SetAt("MEST",	"+0200");	// Middle Europe Summer Time ([bpĎ)
-	map.SetAt("METDST",	"+0200");	// Middle Europe Daylight Time ([bpĎ)
-	map.SetAt("SST",	"+0200");	// Swedish Summer Time (XEF[fĎ)
-	map.SetAt("BST",	"+0100");	// British Summer Time (CMXĎ)
-	map.SetAt("CET",	"+0100");	// Central European Time ([bp)
-	map.SetAt("DNT",	"+0100");	// Dansk Normal Tid (f}[NW)
-	map.SetAt("DST",	"+0100");	// Dansk Standard Time (?) (f}[NW (?))
-	map.SetAt("FST",	"+0100");	// French Summer Time (tXĎ)
-	map.SetAt("MET",	"+0100");	// Middle Europe Time ([bp)
-	map.SetAt("MEWT",	"+0100");	// Middle Europe Winter Time ([bp~)
-	map.SetAt("MEZ",	"+0100");	// Middle Europe Zone ([bp)
-	map.SetAt("NOR",	"+0100");	// Norway Standard Time (mEF[W)
-	map.SetAt("SET",	"+0100");	// Seychelles Time (ZCVF)
-	map.SetAt("SWT",	"+0100");	// Swedish Winter Time (XEF[f~)
-	map.SetAt("WETDST",	"+0100");	// Western Europe Daylight Savings Time ([bpĎ)
-	map.SetAt("GMT",	"+0000");	// Greenwish Mean Time (OjbWW)
-	map.SetAt("WET",	"+0000");	// Western Europe ([bp)
-	map.SetAt("WAT",	"-0100");	// West Africa Time (AtJ)
-	map.SetAt("NDT",	"-0230");	// Newfoundland Daylight Time (j[t@hhĎ)
-	map.SetAt("ADT",	"-0300");	// Atlantic Daylight Time (吼mĎ)
-	map.SetAt("NFT",	"-0330");	// Newfoundland Standard Time (j[t@hhW)
-	map.SetAt("NST",	"-0330");	// Newfoundland Standard Time (j[t@hhW)
-	map.SetAt("AST",	"-0400");	// Atlantic Std Time (Canada) (吼mW (Ji_))
-	map.SetAt("EDT",	"-0400");	// Eastern Daylight Time (AJĎ)
-	map.SetAt("ZP4",	"-0400");	// GMT +4 
-	map.SetAt("CDT",	"-0500");	// Central Daylight Time (AJĎ)
-	map.SetAt("EST",	"-0500");	// Eastern Standard Time (AJW)
-	map.SetAt("ZP5",	"-0500");	// GMT +5 
-	map.SetAt("CST",	"-0600");	// Central Std Time (AJW)
-	map.SetAt("MDT",	"-0600");	// Mountain Daylight Time (AJRxĎ)
-	map.SetAt("ZP6",	"-0600");	// GMT +6 hours (OjbWW +6 )
-	map.SetAt("MST",	"-0700");	// Mountain Standard Time (AJRxW)
-	map.SetAt("PDT",	"-0700");	// Pacific Daylight Time (AJmĎ)
-	map.SetAt("PST",	"-0800");	// Pacific Std Time (AJmW)
-	map.SetAt("YDT",	"-0800");	// Yukon Daylight Time ([RĎ)
-	map.SetAt("HDT",	"-0900");	// Hawaii/Alaska Daylight Time (nC/AXJĎ)
-	map.SetAt("YST",	"-0900");	// Yukon Standard Time ([RW)
-	map.SetAt("AHST",	"-1000");	// Alaska-Hawaii Std Time (AXJ-nCW)
-	map.SetAt("CAT",	"-1000");	// Central Alaska Time (AXJ)
-	map.SetAt("NT",		"-1100");	// Nome Time (m[)
-	map.SetAt("IDLW",	"-1200");	// International Date Line, West (ۓtύXA)
-
-	CString value;
-	map.Lookup(name, value);
-	return value;
-}
-
 // cstringmarkň͂܂ꂽr
-void g_strip_part(CString &buf, char *mark)
+void g_strip_part(CString &buf, LPCTSTR mark)
 {
 	int start = 0;
 	int end;
@@ -677,23 +510,9 @@ void g_strip_part(CString &buf, char *mark)
 	}
 }
 
-// ɔpJi܂܂Ă邩ǂm߂
-/*BOOL g_is_hankana(unsigned char *buf)
-{
-	unsigned char c = *buf;
-	while(c != NULL){
-		// 0xa0 -> 0xdf 
-		if(c >= 0xa0 && c <= 0xdf){
-			return TRUE;
-		}
-		c = *(++buf);
-	}
-	return FALSE;
-}*/
-
 int g_richedit_count_char(CString buf)
 {
-	buf.Replace("\r", "");
+	buf.Replace("\n", "");
 	return _mbsnccnt((const unsigned char *)buf.GetBuffer(0), buf.GetLength());
 }
 
@@ -754,35 +573,242 @@ CString g_simple_decode(const CString& in, const TCHAR seed)
 	return out;
 }
 
-void g_empty_directory(CString path)
+void g_empty_directory(LPCTSTR path)
 {
+	CString tmp;
+
+	tmp.Format("%s\\*.*", path);
 	CFileFind ff;
-	BOOL b = ff.FindFile(path+"\\*.*");
+	BOOL b = ff.FindFile(tmp);
 	if(b){
 		while(b){
 			b = ff.FindNextFile();
 			if(!ff.IsDirectory() && !ff.IsDots()){
-				DeleteFile(path+"\\"+ff.GetFileName());
+				tmp.Format("%s\\%s", path, ff.GetFileName());
+				DeleteFile(tmp);
 			}
 		}
 	}
 }
 
-void g_split_address(CString address, CStringArray *array_address)
+void g_split_address(CString address, CStringArray &array_address, BOOL include_comma, BOOL strip)
 {
-	int pre=0;
-	for(int i=0; i<address.GetLength(); i++){
-		if(address.GetAt(i) == '"'){
-			i++;
-			while(address.GetAt(i) != '"'){
-				i++;
-			}
-			i++;
+	CString buf;
+	BOOL quotation = FALSE;
+	int max = address.GetLength();
+
+	buf.Empty();
+	for(int n=0; n < max; n++){
+		// in case that comment exit in each address field.
+		if(address[n] == '"'){
+			if(quotation == TRUE) quotation = FALSE;
+			else quotation = TRUE;
 		}
-		if(address.GetAt(i) == ','){
-//			array_address->Add(address.Mid(pre, i-pre);
-			pre = i+1;
+		if(!quotation && address[n] == ','){
+			if(include_comma){
+				buf += address[n];
+			}
+			buf.TrimLeft(" ");
+			buf.TrimRight(" ");
+			buf.TrimRight("\r\n");
+			if(strip){
+				buf = g_ma(buf);
+			}
+			array_address.Add(buf);
+			buf.Empty();
+			continue;
+		}
+		buf += address[n];
+	}
+	buf.TrimLeft(" ");
+	buf.TrimRight(" ");
+	buf.TrimRight("\r\n");
+	if(strip){
+		buf = g_ma(buf);
+	}
+	array_address.Add(buf);
+}
+
+void g_glue_address(CString &address, CStringArray &array_address)
+{
+	int size = g_cstringarray_getsize(array_address);
+	int max = array_address.GetSize();
+	char *p = address.GetBuffer(size+max+1);
+	CString buf;
+
+	for(int i=0; i<max; i++){
+		buf = array_address.GetAt(i);
+		buf.TrimRight(",");
+		if(i != max-1){
+			buf += ",";
+		}
+		strcpy(p, buf);
+		p += buf.GetLength();
+	}
+	*p = '\0';
+	address.ReleaseBuffer();
+}
+
+BOOL g_split_name_address(CString in, CString &name, CString &address)
+{
+	int i;
+	int max;
+	BOOL iso_2022 = FALSE;
+
+	name.Empty();
+	address.Empty();
+
+	max = in.GetLength();
+	for(i=0; i<max; i++){
+		if(in[i] == 0x1b){
+			if(!iso_2022)
+				iso_2022 = TRUE;
+			else
+				iso_2022 = FALSE;
+		}else if(in[i] == '<' && !iso_2022){
+			name = in.Left(i);
+			address = in.Mid(i);
+			return TRUE;
 		}
 	}
-//	array_address->Add(address.Mid(pre);
+	return FALSE;
+}
+
+BOOL g_is_all_ascii(CString buf)
+{
+	int n;
+	int max = buf.GetLength();
+	for(n=0; n<max; n++){
+		if(!isascii((int)buf[n])){
+			return FALSE;
+		}
+	}
+	return TRUE;
+}
+
+BOOL g_is_iso2022(CString buf)
+{
+	int n;
+	int max = buf.GetLength();
+	for(n=0; n<max; n++){
+		if(buf[n] == 0x1b){
+			return TRUE;
+		}
+		n++;
+	}
+	return FALSE;
+}
+
+void g_encode_base64(LPCTSTR in, CString &out)
+{
+	if(!strlen(in))
+		return;
+	unsigned char *buf = (unsigned char *)new char[strlen(in)*3];
+	to64frombits(buf, (const unsigned char *)in, strlen(in));
+	out = buf;
+	delete [] buf;
+}
+
+void g_decode_base64(LPCTSTR in, CString &out)
+{
+	if(!strlen(in))
+		return;
+	char *buf = (char *)new char[strlen(in)];
+	int len = from64tobits(buf, in, strlen(in));
+	buf[len] = '\0';
+	out = buf;
+	delete [] buf;
+}
+
+void g_decode_qp(LPCTSTR in, CString &out)
+{
+	char *buf = new char[strlen(in)+10];
+	int len = fromQPtobits(buf, in, strlen(in));
+	buf[len] = '\0';
+	out = buf;
+	delete [] buf;
+}
+
+CString g_get_complete_path(LPCTSTR path)
+{
+	CString tmp = path;
+
+	// if path include "\..\", remove
+	LPCTSTR regex = "[^\\\\]+\\\\\\.\\.\\\\";
+	regex_t reg; // for regex
+	regmatch_t pmatch[1]; // result of regexec is put into this
+	regcomp(&reg, regex, REG_EXTENDED | REG_NEWLINE | REG_ICASE);
+	while(0 == regexec(&reg, tmp, 1, pmatch, 0)){
+		tmp = tmp.Left(pmatch[0].rm_so) + tmp.Mid(pmatch[0].rm_eo);
+	}
+	regfree(&reg);
+
+	return tmp;
+}
+
+BOOL g_get_header(LPCTSTR path, CStringArray &header)
+{
+	CStdioFile sf;
+	CString buf;
+	int i;
+	
+	header.RemoveAll();
+	header.SetSize(50);
+
+	if(!sf.Open(path, CFile::modeRead | CFile::typeText)){
+		return FALSE;
+	}
+
+	i = 0;
+	while(sf.ReadString(buf)){
+		if(buf == ""){
+			break;
+		}
+		if(i == header.GetSize()){
+			header.SetSize(header.GetSize()+1);
+		}
+		header.SetAt(i, buf);
+		i++;
+	}
+
+	for(i=header.GetSize()-1; i>=0; i--){
+		if(header.GetAt(i).IsEmpty()){
+			header.RemoveAt(i);
+		}else{
+			break;
+		}
+	}
+
+	sf.Close();
+	return TRUE;
+}
+
+CString g_get_relative_path(LPCTSTR org_path, LPCTSTR dst_path)
+{
+	CString path;
+	CString org = org_path;
+	CString dst = dst_path;
+	CStringArray org_array;
+	CStringArray dst_array;
+	int i, j;
+
+	org.MakeLower();
+	dst.MakeLower();
+
+	g_string2cstringarray(org, org_array, "\\", FALSE);
+	g_string2cstringarray(dst, dst_array, "\\", FALSE);
+
+	int max_org = org_array.GetSize();
+	int max_dst = dst_array.GetSize();
+	for(i=0; org_array[i] == dst_array[i] && i < max_org && i < max_dst; i++);
+
+	for(j=i; j<max_org; j++){
+		path += "\\..";
+	}
+
+	for(j=i; j<max_dst; j++){
+		path += "\\"+dst_array[j];
+	}
+
+	return path;
 }
\ No newline at end of file
