@@ -55,7 +55,10 @@ BOOL CPochyApp::InitInstance()
 	CString path;
 	int point;
 
-	// dN̖h~ƊɋNĂꍇforefroudɂ
+	// get time zone offset from ini
+	m_time_zone_offset = GetProfileString("TimeZone", "OffSet", "+0900");
+
+	// dN̖h~ƊɋNĂꍇforegroudɂ
 	HANDLE mutex = CreateMutex(NULL, TRUE, "GPG_Mailer_Pochy_!");
 	if(!mutex)
 		return FALSE;
@@ -89,7 +92,7 @@ BOOL CPochyApp::InitInstance()
 	// 폜ĂB
 //	if(!AfxSocketInit()){
 //		AfxMessageBox("\Pbg̏Ɏs܂B");
-//		return FALSE;
+//		return FALSE;a
 //	}
 
 #ifdef _AFXDLL
@@ -102,7 +105,7 @@ BOOL CPochyApp::InitInstance()
 	// TODO: ̕AЖ܂͏ȂǓK؂Ȃ̂
 	// ύXĂB
 
-	// ݈ʒũtpX擾Asetting.iniւ̃pX쐬
+	// get current directory path for later reference
 	GetModuleFileName(NULL, path.GetBuffer(1024), 1024); // -> 1024pXԂƗ̂ŗv
 	path.ReleaseBuffer();
 	point = path.ReverseFind('\\');
@@ -113,24 +116,27 @@ BOOL CPochyApp::InitInstance()
 	// if some file that is required for pochy is missing, create those file. 
 	// you run pochy first time, this may be occured.
 	if(!g_is_there(this->m_app_path+"\\address.csv")){
-		g_fcreate(this->m_app_path+"\\address.csv");
+		g_file_create(this->m_app_path+"\\address.csv");
 	}
 
-	// WXgł͂ȂApochy.exeƓtH_init@CɃZbeBOۑ
+	// change registry to ini
 	free((void *)m_pszProfileName);
-	m_pszProfileName = _tcsdup(path.GetBuffer(0));	//͂܂
+	m_pszProfileName = _tcsdup(path);
 	LoadStdProfileSettings();  // W INI t@C̃IvV[ނ܂ (MRU ܂)
 
-	// GPG
+	// gpg
 	CGpg gpg;
 	m_gpg_enable = gpg.Check();
 	m_gpg_passphrase.Empty();
 
+	// call plugin
+	m_pluginManager.LoadAllPlugins();
+
 	// skin.ini
 	CString skinPath = GetProfileString("Skin", "Path", NULL);
 	if(skinPath != "") {
-		if(g_is_there(skinPath.GetBuffer(0))) {
-			LoadSkinProfile(skinPath.GetBuffer(0));
+		if(g_is_there(skinPath)) {
+			LoadSkinProfile(skinPath);
 		}
 	}
 
@@ -143,7 +149,7 @@ BOOL CPochyApp::InitInstance()
 		RUNTIME_CLASS(CTextView));
 	AddDocTemplate(pDoc1Template);
 
-	// init@C wndPlace Zoom=1 ̏ꍇEBhEő剻ċN
+	// in case of wndPlace Zoom == 1 in setting.ini, mainframe is maximize.
 	bool bMaximize = GetProfileInt("wndPlace", "Zoom", 1) == 1;
 	bool bMinimize = GetProfileInt("Customize", "Minimize", 0) == 1;
 
@@ -167,6 +173,34 @@ BOOL CPochyApp::InitInstance()
 	if (!ProcessShellCommand(cmdInfo))
 		return FALSE;
 
+	// GPG, Plugin Ƃ̓j[\ɂ
+	HMENU hMenu = ::GetMenu(m_pMainWnd->GetSafeHwnd());
+	// j[폜Əς邽ߐԍZbg
+	int nGPGMenuPos = 4;
+	int nPluginMenuPos = 5;
+	int nHelpMenuPos = 6;
+	if (hMenu != NULL)
+	{
+		if (!m_gpg_enable)
+		{
+			::DeleteMenu(hMenu, nGPGMenuPos, MF_BYPOSITION);
+			nGPGMenuPos = -1; // 폜ꂽ邵Ƃ -1
+			nPluginMenuPos--;
+			nHelpMenuPos--;
+		}
+		if (m_pluginManager.GetPluginList().size() <= 0)
+		{
+			::DeleteMenu(hMenu, nPluginMenuPos, MF_BYPOSITION);
+			nPluginMenuPos = -1; // 폜ꂽ邵Ƃ -1
+			nHelpMenuPos--;
+		}
+		if (nGPGMenuPos == -1 || nPluginMenuPos == -1)
+		{
+			::DrawMenuBar(m_pMainWnd->GetSafeHwnd());
+		}
+	}
+
+	// C EBhEꂽ̂ŁA\ƍXVs܂B
 	if (bMinimize && bMaximize)
 	{
 		WINDOWPLACEMENT wp;
@@ -177,7 +211,6 @@ BOOL CPochyApp::InitInstance()
 		m_pMainWnd->SetWindowPlacement(&wp);
 	}
 
-	// C EBhEꂽ̂ŁA\ƍXVs܂B
 	if(bMinimize){
 		if(this->GetProfileInt("TaskTray", "TaskTrayOnly", 0) ||
 			this->GetProfileInt("TaskTray", "UseTaskTray", 0)){
@@ -185,7 +218,7 @@ BOOL CPochyApp::InitInstance()
 		}
 	}
 	this->m_pMainWnd->UpdateWindow();
-	
+
 	// L[{[hV[gJbg̐ݒ
 	((CMainFrame*)m_pMainWnd)->LoadDefaultAccelerator();
 	((CMainFrame*)m_pMainWnd)->SetAcceleratorTargetWindow();
@@ -241,11 +274,58 @@ BOOL CPochyApp::InitInstance()
 			this->CreateDraftFrame(((CMainFrame *)this->m_pMainWnd)->m_pAcntV->GetFirstAccountName());
 		}
 	}
+
+	// plugin j[Ăяo
+	if (hMenu != NULL)
+	{
+		for (int i = 0; i < ::GetMenuItemCount(hMenu); i++)
+		{
+			HMENU hSubMenu = ::GetSubMenu(hMenu, i);
+			if (hSubMenu != NULL)
+			{
+				POCHY_MENU_TYPE nMenuType = POCHY_MENU_FILE;
+				switch (i)
+				{
+				case 0: nMenuType = POCHY_MENU_FILE; break;
+				case 1: nMenuType = POCHY_MENU_MAIL; break;
+				case 2: nMenuType = POCHY_MENU_VIEW; break;
+				case 3: nMenuType = POCHY_MENU_SETTING; break;
+				default:
+					{
+						if (i == nGPGMenuPos)
+						{
+							nMenuType = POCHY_MENU_GPG;
+						}
+						else if (i == nPluginMenuPos)
+						{
+							nMenuType = POCHY_MENU_PLUGIN;
+						}
+						else if (i == nHelpMenuPos)
+						{
+							nMenuType = POCHY_MENU_HELP;
+						}
+					}
+					break;
+				}
+				m_pluginManager.OnInitMenu(hSubMenu, nMenuType);
+			}
+		}
+	}
+	HMENU hSystemMenu = ::GetSystemMenu(m_pMainWnd->GetSafeHwnd(), FALSE);
+	if (hSystemMenu != NULL)
+	{
+		m_pluginManager.OnInitMenu(hSystemMenu, POCHY_MENU_SYSTEM);
+//		::GetSystemMenu(m_pMainWnd->GetSafeHwnd(), TRUE);
+	}
+
+	// call plugin
+	m_pluginManager.OnOpen();
+
 	return TRUE;
 }
 
 // skin.inĩ[h
-BOOL CPochyApp::LoadSkinProfile(char *skinIniFile) {
+BOOL CPochyApp::LoadSkinProfile(LPCTSTR skinIniFile) {
 	return m_skin.LoadSkinProfile(skinIniFile);
 }
 
