@@ -17,6 +17,7 @@
 #include "resource.h"       // C V{
 #include "draftframe.h"
 #include "MimeEncode.h"
+#include "Plugin.h"
 
 #define WM_END (WM_USER+101)
 #define WM_PROGCREATE (WM_USER+102)
@@ -43,26 +44,28 @@
 #define DEF_HEADER_INFO_COLOR_R (128)	// default color of header info
 #define DEF_HEADER_INFO_COLOR_G (255)
 #define DEF_HEADER_INFO_COLOR_B (0)
-#define DEF_BOXNAME_INBOX "M"		// default name of inbox
-#define DEF_BOXNAME_OUTBOX "Mς"	// default name of outbox
-#define DEF_BOXNAME_DRAFT "e"		// default name of draft
-#define DEF_BOXNAME_TRASH "S~"		// default name of trash
+#define DEF_BOXNAME_INBOX _T("M")		// default name of inbox
+#define DEF_BOXNAME_OUTBOX _T("Mς")	// default name of outbox
+#define DEF_BOXNAME_DRAFT _T("e")		// default name of draft
+#define DEF_BOXNAME_TRASH _T("S~")		// default name of trash
 #ifdef _IPV6_
-#define X_MAILER "Pochy 0.2 IPv6 ready"	// x-mailer of ipv6 ready version
-#define VERSION "Pochy 0.2 IPv6 ready"	// version info of ipv6 ready version
+#define X_MAILER "Pochy 0.2.1a IPv6 ready"	// x-mailer of ipv6 ready version
+#define VERSION "Pochy 0.2.1a IPv6 ready"	// version info of ipv6 ready version
 #else
-#define X_MAILER "Pochy 0.2"				// x-mailer of normal version
-#define VERSION "Pochy 0.2"				// version info of ipv6 ready version
+#define X_MAILER "Pochy 0.2.1a"				// x-mailer of normal version
+#define VERSION "Pochy 0.2.1a"				// version info of ipv6 ready version
 #endif
-#define COPYRIGHT "Copyright (C) 2003 Pochy project team"
+#define COPYRIGHT "Copyright (C) 2003-2004 Pochy project team"
 #define CONTRIBUTORS "\
-Portions of this software are Copyright (C) 2003 by minamina\r\n\
+Portions of this software are Copyright (C) 2003-2004 by minamina\r\n\
 Portions of this software are Copyright (C) 2003 by xken\r\n\
 Portions of this software are Copyright (C) 2003 by ajishio_taro\r\n"
 #define DEF_TIME_ZONE "+0900"			// default time zone
+#define DEF_TIME_FORMAT "%Y %b %d %H:%M:%S "
 #define DEF_POP_PORT "110"				// default pop port
 #define DEF_SMTP_PORT "25"				// default smtp port
 #define BUF_LENGTH (255)				// default buffer max length
+#define LISTCTRL_BUF_LENGTH (2048)
 #define FILTER_INSTRUCTION "\
 # ݂̂ƂA[̐U蕪ݒGUIł͂ł܂B\r\n\
 # 蓮Őݒt@CKv܂B \r\n\
@@ -81,7 +84,12 @@ From=hoge@hoge.com\r\n\
 # w肵tH_݂Ȃꍇ͎Iɍ쐬܂B\r\n\
 # `ƒ`̊Ԃ͏L̂悤ɕK#ŋ؂ĂB\r\n\
 # ݂̂ƂAU蕪ɂ̓wb_񂵂pł܂B\r\n\
-# ҏWA㏑ۑĂB\r\n"
+# ҏWA㏑ۑĂB\r\n\
+#\r\n\
+# ̑A\r\n\
+# - ̃tH_ɐU蕪\r\n\
+# - K\g\r\n\
+# ɂĂhttp://pochy.sourceforge.jp̃hLgQƂB\r\n"
 
 #define WM_USER_NOTIFYICON (WM_APP + 100)
 #define TOOLBAR_MAIN_FILENAME _T("\\skin\\toolbar_main.bmp")
@@ -90,13 +98,10 @@ From=hoge@hoge.com\r\n\
 #define TASKTRAY_ANIMATION_TIMER_ID (200)
 #define NUMBER_OF_TOOLBAR_MAIN_ICON (10)
 
-#define DEF_HEADER_TEMPLATE "To: %t\r\n\
-From: %f\r\n\
-Subject: %s\r\n\
-Date: %d\r\n\
-Cc: %c\r\n\
-Reply-To: %r\r\n\
-X-Mailer: %m"
+#define DEF_HEADER_TEMPLATE "\
+ol: %f  : %t\r\n\
+: %s  t: %d\r\n\
+x-mailer: %[x-mailer]"
 
 #define DEF_REPLY_TEMPLATE "\r\n\
 On %d\r\n\
@@ -106,7 +111,7 @@ On %d\r\n\
 %S"
 
 #define DEF_FORWARD_TEMPLATE "\r\n\
-Fowarded by %a\r\n\
+Forwarded by %a\r\n\
 ----- Original Message -----\r\n\
 From: %f\r\n\
 To: %t\r\n\
@@ -147,13 +152,15 @@ private:
 	CSingleDocTemplate* pDoc2Template;
 	CSingleDocTemplate* pDoc1Template;
 public:
+	CPluginManager m_pluginManager;
 	void CreateDraftFrame(CString acocunt);
-	BOOL LoadSkinProfile(char *skinIniFile);
+	BOOL LoadSkinProfile(LPCTSTR skinIniFile);
 // oϐ
 	CArray<CDraftFrame *, CDraftFrame *> m_draft_array;
 	CString m_gpg_passphrase;
-	CString m_keyword;			// Ώ
-	CString m_app_path;			// vO{̂fBNg
+	CString m_keyword;			// this is for consecutive search
+	CString m_app_path;			// this is path for directory in which pochy.exe is
+	CString m_time_zone_offset;	// this effect summary date and so on
 	BOOL m_retrieving;
 	BOOL m_gpg_enable;
 	BOOL m_ipv6_enable;
