@@ -42,7 +42,7 @@ int qp_char(unsigned char c1, unsigned char c2, unsigned char *c_out)
 	}
 }
 
-int fromQPtobits(char *out, char *in, int maxlen)
+int fromQPtobits(char *out, const char *in, int maxlen)
 {	
 	int len = 0;
 
